from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.dqo_user_role import DqoUserRole
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dqo_user_roles_model_data_domain_roles import (
        DqoUserRolesModelDataDomainRoles,
    )


T = TypeVar("T", bound="DqoUserRolesModel")


@_attrs_define
class DqoUserRolesModel:
    """DQOps user model - identifies a user in a multi-user DQOps deployment and the user's roles.

    Attributes:
        email (Union[Unset, str]): User's email that identifies the user.
        account_role (Union[Unset, DqoUserRole]):
        data_domain_roles (Union[Unset, DqoUserRolesModelDataDomainRoles]): User roles within each data domain. Data
            domains are supported in an ENTERPRISE version of DQOps and they are managed by the SaaS components of DQOps
            Cloud.
    """

    email: Union[Unset, str] = UNSET
    account_role: Union[Unset, DqoUserRole] = UNSET
    data_domain_roles: Union[Unset, "DqoUserRolesModelDataDomainRoles"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        email = self.email
        account_role: Union[Unset, str] = UNSET
        if not isinstance(self.account_role, Unset):
            account_role = self.account_role.value

        data_domain_roles: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_domain_roles, Unset):
            data_domain_roles = self.data_domain_roles.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if email is not UNSET:
            field_dict["email"] = email
        if account_role is not UNSET:
            field_dict["accountRole"] = account_role
        if data_domain_roles is not UNSET:
            field_dict["dataDomainRoles"] = data_domain_roles

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dqo_user_roles_model_data_domain_roles import (
            DqoUserRolesModelDataDomainRoles,
        )

        d = src_dict.copy()
        email = d.pop("email", UNSET)

        _account_role = d.pop("accountRole", UNSET)
        account_role: Union[Unset, DqoUserRole]
        if isinstance(_account_role, Unset):
            account_role = UNSET
        else:
            account_role = DqoUserRole(_account_role)

        _data_domain_roles = d.pop("dataDomainRoles", UNSET)
        data_domain_roles: Union[Unset, DqoUserRolesModelDataDomainRoles]
        if isinstance(_data_domain_roles, Unset):
            data_domain_roles = UNSET
        else:
            data_domain_roles = DqoUserRolesModelDataDomainRoles.from_dict(
                _data_domain_roles
            )

        dqo_user_roles_model = cls(
            email=email,
            account_role=account_role,
            data_domain_roles=data_domain_roles,
        )

        dqo_user_roles_model.additional_properties = d
        return dqo_user_roles_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.check_type import CheckType
from ..models.time_period_gradient import TimePeriodGradient
from ..types import UNSET, Unset

T = TypeVar("T", bound="SensorReadoutEntryModel")


@_attrs_define
class SensorReadoutEntryModel:
    """
    Attributes:
        id (Union[Unset, str]): Sensor readout primary key
        check_name (Union[Unset, str]): Check name
        check_display_name (Union[Unset, str]): Check display name
        check_type (Union[Unset, CheckType]):
        actual_value (Union[Unset, float]): Actual value
        expected_value (Union[Unset, float]): Expected value
        column_name (Union[Unset, str]): Column name
        data_group (Union[Unset, str]): Data group
        duration_ms (Union[Unset, int]): Duration (ms)
        executed_at (Union[Unset, int]): Executed at
        time_gradient (Union[Unset, TimePeriodGradient]):
        time_period (Union[Unset, datetime.datetime]): Time period
        provider (Union[Unset, str]): Provider name
        quality_dimension (Union[Unset, str]): Data quality dimension
        table_comparison (Union[Unset, str]): Table comparison name
    """

    id: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    check_display_name: Union[Unset, str] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    actual_value: Union[Unset, float] = UNSET
    expected_value: Union[Unset, float] = UNSET
    column_name: Union[Unset, str] = UNSET
    data_group: Union[Unset, str] = UNSET
    duration_ms: Union[Unset, int] = UNSET
    executed_at: Union[Unset, int] = UNSET
    time_gradient: Union[Unset, TimePeriodGradient] = UNSET
    time_period: Union[Unset, datetime.datetime] = UNSET
    provider: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    table_comparison: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        check_name = self.check_name
        check_display_name = self.check_display_name
        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        actual_value = self.actual_value
        expected_value = self.expected_value
        column_name = self.column_name
        data_group = self.data_group
        duration_ms = self.duration_ms
        executed_at = self.executed_at
        time_gradient: Union[Unset, str] = UNSET
        if not isinstance(self.time_gradient, Unset):
            time_gradient = self.time_gradient.value

        time_period: Union[Unset, str] = UNSET
        if not isinstance(self.time_period, Unset):
            time_period = self.time_period.isoformat()

        provider = self.provider
        quality_dimension = self.quality_dimension
        table_comparison = self.table_comparison

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if check_display_name is not UNSET:
            field_dict["checkDisplayName"] = check_display_name
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if actual_value is not UNSET:
            field_dict["actualValue"] = actual_value
        if expected_value is not UNSET:
            field_dict["expectedValue"] = expected_value
        if column_name is not UNSET:
            field_dict["columnName"] = column_name
        if data_group is not UNSET:
            field_dict["dataGroup"] = data_group
        if duration_ms is not UNSET:
            field_dict["durationMs"] = duration_ms
        if executed_at is not UNSET:
            field_dict["executedAt"] = executed_at
        if time_gradient is not UNSET:
            field_dict["timeGradient"] = time_gradient
        if time_period is not UNSET:
            field_dict["timePeriod"] = time_period
        if provider is not UNSET:
            field_dict["provider"] = provider
        if quality_dimension is not UNSET:
            field_dict["qualityDimension"] = quality_dimension
        if table_comparison is not UNSET:
            field_dict["tableComparison"] = table_comparison

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        check_name = d.pop("checkName", UNSET)

        check_display_name = d.pop("checkDisplayName", UNSET)

        _check_type = d.pop("checkType", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        actual_value = d.pop("actualValue", UNSET)

        expected_value = d.pop("expectedValue", UNSET)

        column_name = d.pop("columnName", UNSET)

        data_group = d.pop("dataGroup", UNSET)

        duration_ms = d.pop("durationMs", UNSET)

        executed_at = d.pop("executedAt", UNSET)

        _time_gradient = d.pop("timeGradient", UNSET)
        time_gradient: Union[Unset, TimePeriodGradient]
        if isinstance(_time_gradient, Unset):
            time_gradient = UNSET
        else:
            time_gradient = TimePeriodGradient(_time_gradient)

        _time_period = d.pop("timePeriod", UNSET)
        time_period: Union[Unset, datetime.datetime]
        if isinstance(_time_period, Unset):
            time_period = UNSET
        else:
            time_period = isoparse(_time_period)

        provider = d.pop("provider", UNSET)

        quality_dimension = d.pop("qualityDimension", UNSET)

        table_comparison = d.pop("tableComparison", UNSET)

        sensor_readout_entry_model = cls(
            id=id,
            check_name=check_name,
            check_display_name=check_display_name,
            check_type=check_type,
            actual_value=actual_value,
            expected_value=expected_value,
            column_name=column_name,
            data_group=data_group,
            duration_ms=duration_ms,
            executed_at=executed_at,
            time_gradient=time_gradient,
            time_period=time_period,
            provider=provider,
            quality_dimension=quality_dimension,
            table_comparison=table_comparison,
        )

        sensor_readout_entry_model.additional_properties = d
        return sensor_readout_entry_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.all_checks_patch_parameters_selected_tables_to_columns import (
        AllChecksPatchParametersSelectedTablesToColumns,
    )
    from ..models.check_model import CheckModel
    from ..models.check_search_filters import CheckSearchFilters


T = TypeVar("T", bound="AllChecksPatchParameters")


@_attrs_define
class AllChecksPatchParameters:
    """Parameter object for creating pruned patch trees of all checks that fit the filters.

    Attributes:
        check_search_filters (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        check_model_patch (Union[Unset, CheckModel]): Model that returns the form definition and the form data to edit a
            single data quality check.
        selected_tables_to_columns (Union[Unset, AllChecksPatchParametersSelectedTablesToColumns]): List of concrete
            table and column names which will be the target. Column mappings are ignored for table level checks. This filter
            is applied at the end.
        override_conflicts (Union[Unset, bool]): Override existing configurations if they're present. If false, apply
            updates only to the fields for which no configuration exists.
    """

    check_search_filters: Union[Unset, "CheckSearchFilters"] = UNSET
    check_model_patch: Union[Unset, "CheckModel"] = UNSET
    selected_tables_to_columns: Union[
        Unset, "AllChecksPatchParametersSelectedTablesToColumns"
    ] = UNSET
    override_conflicts: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_search_filters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_search_filters, Unset):
            check_search_filters = self.check_search_filters.to_dict()

        check_model_patch: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_model_patch, Unset):
            check_model_patch = self.check_model_patch.to_dict()

        selected_tables_to_columns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.selected_tables_to_columns, Unset):
            selected_tables_to_columns = self.selected_tables_to_columns.to_dict()

        override_conflicts = self.override_conflicts

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_search_filters is not UNSET:
            field_dict["check_search_filters"] = check_search_filters
        if check_model_patch is not UNSET:
            field_dict["check_model_patch"] = check_model_patch
        if selected_tables_to_columns is not UNSET:
            field_dict["selected_tables_to_columns"] = selected_tables_to_columns
        if override_conflicts is not UNSET:
            field_dict["override_conflicts"] = override_conflicts

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.all_checks_patch_parameters_selected_tables_to_columns import (
            AllChecksPatchParametersSelectedTablesToColumns,
        )
        from ..models.check_model import CheckModel
        from ..models.check_search_filters import CheckSearchFilters

        d = src_dict.copy()
        _check_search_filters = d.pop("check_search_filters", UNSET)
        check_search_filters: Union[Unset, CheckSearchFilters]
        if isinstance(_check_search_filters, Unset):
            check_search_filters = UNSET
        else:
            check_search_filters = CheckSearchFilters.from_dict(_check_search_filters)

        _check_model_patch = d.pop("check_model_patch", UNSET)
        check_model_patch: Union[Unset, CheckModel]
        if isinstance(_check_model_patch, Unset):
            check_model_patch = UNSET
        else:
            check_model_patch = CheckModel.from_dict(_check_model_patch)

        _selected_tables_to_columns = d.pop("selected_tables_to_columns", UNSET)
        selected_tables_to_columns: Union[
            Unset, AllChecksPatchParametersSelectedTablesToColumns
        ]
        if isinstance(_selected_tables_to_columns, Unset):
            selected_tables_to_columns = UNSET
        else:
            selected_tables_to_columns = (
                AllChecksPatchParametersSelectedTablesToColumns.from_dict(
                    _selected_tables_to_columns
                )
            )

        override_conflicts = d.pop("override_conflicts", UNSET)

        all_checks_patch_parameters = cls(
            check_search_filters=check_search_filters,
            check_model_patch=check_model_patch,
            selected_tables_to_columns=selected_tables_to_columns,
            override_conflicts=override_conflicts,
        )

        all_checks_patch_parameters.additional_properties = d
        return all_checks_patch_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="BetweenIntsRuleParametersSpec")


@_attrs_define
class BetweenIntsRuleParametersSpec:
    """
    Attributes:
        from_ (Union[Unset, int]): Minimum accepted value for the actual_value returned by the sensor (inclusive).
        to (Union[Unset, int]): Maximum accepted value for the actual_value returned by the sensor (inclusive).
    """

    from_: Union[Unset, int] = UNSET
    to: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from_ = self.from_
        to = self.to

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if from_ is not UNSET:
            field_dict["from"] = from_
        if to is not UNSET:
            field_dict["to"] = to

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        from_ = d.pop("from", UNSET)

        to = d.pop("to", UNSET)

        between_ints_rule_parameters_spec = cls(
            from_=from_,
            to=to,
        )

        between_ints_rule_parameters_spec.additional_properties = d
        return between_ints_rule_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.my_sql_ssl_mode import MySqlSslMode
from ..models.mysql_engine_type import MysqlEngineType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.mysql_parameters_spec_properties import MysqlParametersSpecProperties
    from ..models.single_store_db_parameters_spec import SingleStoreDbParametersSpec


T = TypeVar("T", bound="MysqlParametersSpec")


@_attrs_define
class MysqlParametersSpec:
    """
    Attributes:
        host (Union[Unset, str]): MySQL host name. Supports also a ${MYSQL_HOST} configuration with a custom environment
            variable.
        port (Union[Unset, str]): MySQL port number. The default port is 3306. Supports also a ${MYSQL_PORT}
            configuration with a custom environment variable.
        database (Union[Unset, str]): MySQL database name. The value can be in the ${ENVIRONMENT_VARIABLE_NAME} format
            to use dynamic substitution.
        user (Union[Unset, str]): MySQL user name. The value can be in the ${ENVIRONMENT_VARIABLE_NAME} format to use
            dynamic substitution.
        password (Union[Unset, str]): MySQL database password. The value can be in the ${ENVIRONMENT_VARIABLE_NAME}
            format to use dynamic substitution.
        sslmode (Union[Unset, MySqlSslMode]):
        single_store_db_parameters_spec (Union[Unset, SingleStoreDbParametersSpec]):
        mysql_engine_type (Union[Unset, MysqlEngineType]):
        properties (Union[Unset, MysqlParametersSpecProperties]): A dictionary of custom JDBC parameters that are added
            to the JDBC connection string, a key/value dictionary.
    """

    host: Union[Unset, str] = UNSET
    port: Union[Unset, str] = UNSET
    database: Union[Unset, str] = UNSET
    user: Union[Unset, str] = UNSET
    password: Union[Unset, str] = UNSET
    sslmode: Union[Unset, MySqlSslMode] = UNSET
    single_store_db_parameters_spec: Union[Unset, "SingleStoreDbParametersSpec"] = UNSET
    mysql_engine_type: Union[Unset, MysqlEngineType] = UNSET
    properties: Union[Unset, "MysqlParametersSpecProperties"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        host = self.host
        port = self.port
        database = self.database
        user = self.user
        password = self.password
        sslmode: Union[Unset, str] = UNSET
        if not isinstance(self.sslmode, Unset):
            sslmode = self.sslmode.value

        single_store_db_parameters_spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.single_store_db_parameters_spec, Unset):
            single_store_db_parameters_spec = (
                self.single_store_db_parameters_spec.to_dict()
            )

        mysql_engine_type: Union[Unset, str] = UNSET
        if not isinstance(self.mysql_engine_type, Unset):
            mysql_engine_type = self.mysql_engine_type.value

        properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.properties, Unset):
            properties = self.properties.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if host is not UNSET:
            field_dict["host"] = host
        if port is not UNSET:
            field_dict["port"] = port
        if database is not UNSET:
            field_dict["database"] = database
        if user is not UNSET:
            field_dict["user"] = user
        if password is not UNSET:
            field_dict["password"] = password
        if sslmode is not UNSET:
            field_dict["sslmode"] = sslmode
        if single_store_db_parameters_spec is not UNSET:
            field_dict["single_store_db_parameters_spec"] = (
                single_store_db_parameters_spec
            )
        if mysql_engine_type is not UNSET:
            field_dict["mysql_engine_type"] = mysql_engine_type
        if properties is not UNSET:
            field_dict["properties"] = properties

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.mysql_parameters_spec_properties import (
            MysqlParametersSpecProperties,
        )
        from ..models.single_store_db_parameters_spec import SingleStoreDbParametersSpec

        d = src_dict.copy()
        host = d.pop("host", UNSET)

        port = d.pop("port", UNSET)

        database = d.pop("database", UNSET)

        user = d.pop("user", UNSET)

        password = d.pop("password", UNSET)

        _sslmode = d.pop("sslmode", UNSET)
        sslmode: Union[Unset, MySqlSslMode]
        if isinstance(_sslmode, Unset):
            sslmode = UNSET
        else:
            sslmode = MySqlSslMode(_sslmode)

        _single_store_db_parameters_spec = d.pop(
            "single_store_db_parameters_spec", UNSET
        )
        single_store_db_parameters_spec: Union[Unset, SingleStoreDbParametersSpec]
        if isinstance(_single_store_db_parameters_spec, Unset):
            single_store_db_parameters_spec = UNSET
        else:
            single_store_db_parameters_spec = SingleStoreDbParametersSpec.from_dict(
                _single_store_db_parameters_spec
            )

        _mysql_engine_type = d.pop("mysql_engine_type", UNSET)
        mysql_engine_type: Union[Unset, MysqlEngineType]
        if isinstance(_mysql_engine_type, Unset):
            mysql_engine_type = UNSET
        else:
            mysql_engine_type = MysqlEngineType(_mysql_engine_type)

        _properties = d.pop("properties", UNSET)
        properties: Union[Unset, MysqlParametersSpecProperties]
        if isinstance(_properties, Unset):
            properties = UNSET
        else:
            properties = MysqlParametersSpecProperties.from_dict(_properties)

        mysql_parameters_spec = cls(
            host=host,
            port=port,
            database=database,
            user=user,
            password=password,
            sslmode=sslmode,
            single_store_db_parameters_spec=single_store_db_parameters_spec,
            mysql_engine_type=mysql_engine_type,
            properties=properties,
        )

        mysql_parameters_spec.additional_properties = d
        return mysql_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.bulk_check_deactivate_parameters_selected_tables_to_columns import (
        BulkCheckDeactivateParametersSelectedTablesToColumns,
    )
    from ..models.check_search_filters import CheckSearchFilters


T = TypeVar("T", bound="BulkCheckDeactivateParameters")


@_attrs_define
class BulkCheckDeactivateParameters:
    """Parameter object for deactivating all checks that fit the filters.

    Attributes:
        check_search_filters (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        selected_tables_to_columns (Union[Unset, BulkCheckDeactivateParametersSelectedTablesToColumns]): List of
            concrete table and column names which will be the target. Column mappings are ignored for table level checks.
            This filter is applied at the end.
    """

    check_search_filters: Union[Unset, "CheckSearchFilters"] = UNSET
    selected_tables_to_columns: Union[
        Unset, "BulkCheckDeactivateParametersSelectedTablesToColumns"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_search_filters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.check_search_filters, Unset):
            check_search_filters = self.check_search_filters.to_dict()

        selected_tables_to_columns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.selected_tables_to_columns, Unset):
            selected_tables_to_columns = self.selected_tables_to_columns.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_search_filters is not UNSET:
            field_dict["check_search_filters"] = check_search_filters
        if selected_tables_to_columns is not UNSET:
            field_dict["selected_tables_to_columns"] = selected_tables_to_columns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.bulk_check_deactivate_parameters_selected_tables_to_columns import (
            BulkCheckDeactivateParametersSelectedTablesToColumns,
        )
        from ..models.check_search_filters import CheckSearchFilters

        d = src_dict.copy()
        _check_search_filters = d.pop("check_search_filters", UNSET)
        check_search_filters: Union[Unset, CheckSearchFilters]
        if isinstance(_check_search_filters, Unset):
            check_search_filters = UNSET
        else:
            check_search_filters = CheckSearchFilters.from_dict(_check_search_filters)

        _selected_tables_to_columns = d.pop("selected_tables_to_columns", UNSET)
        selected_tables_to_columns: Union[
            Unset, BulkCheckDeactivateParametersSelectedTablesToColumns
        ]
        if isinstance(_selected_tables_to_columns, Unset):
            selected_tables_to_columns = UNSET
        else:
            selected_tables_to_columns = (
                BulkCheckDeactivateParametersSelectedTablesToColumns.from_dict(
                    _selected_tables_to_columns
                )
            )

        bulk_check_deactivate_parameters = cls(
            check_search_filters=check_search_filters,
            selected_tables_to_columns=selected_tables_to_columns,
        )

        bulk_check_deactivate_parameters.additional_properties = d
        return bulk_check_deactivate_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_lineage_source_spec_properties import (
        ColumnLineageSourceSpecProperties,
    )


T = TypeVar("T", bound="ColumnLineageSourceSpec")


@_attrs_define
class ColumnLineageSourceSpec:
    """
    Attributes:
        source_columns (Union[Unset, List[str]]): A list of source columns from the source table name from which this
            column receives data.
        properties (Union[Unset, ColumnLineageSourceSpecProperties]): A dictionary of mapping properties stored as a
            key/value dictionary. Data lineage synchronization tools that are importing data lineage mappings from external
            data lineage sources can use it to store mapping information.
    """

    source_columns: Union[Unset, List[str]] = UNSET
    properties: Union[Unset, "ColumnLineageSourceSpecProperties"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source_columns: Union[Unset, List[str]] = UNSET
        if not isinstance(self.source_columns, Unset):
            source_columns = self.source_columns

        properties: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.properties, Unset):
            properties = self.properties.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source_columns is not UNSET:
            field_dict["source_columns"] = source_columns
        if properties is not UNSET:
            field_dict["properties"] = properties

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_lineage_source_spec_properties import (
            ColumnLineageSourceSpecProperties,
        )

        d = src_dict.copy()
        source_columns = cast(List[str], d.pop("source_columns", UNSET))

        _properties = d.pop("properties", UNSET)
        properties: Union[Unset, ColumnLineageSourceSpecProperties]
        if isinstance(_properties, Unset):
            properties = UNSET
        else:
            properties = ColumnLineageSourceSpecProperties.from_dict(_properties)

        column_lineage_source_spec = cls(
            source_columns=source_columns,
            properties=properties,
        )

        column_lineage_source_spec.additional_properties = d
        return column_lineage_source_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class DatetimeBuiltInDateFormats(str, Enum):
    DDMMYYYY = "DD/MM/YYYY"
    DD_MM_YYYY = "DD.MM.YYYY"
    YYYY_MM_DD = "YYYY-MM-DD"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class MySqlSslMode(str, Enum):
    DISABLED = "DISABLED"
    PREFERRED = "PREFERRED"
    REQUIRED = "REQUIRED"
    VERIFY_CA = "VERIFY_CA"
    VERIFY_IDENTITY = "VERIFY_IDENTITY"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_integer_in_range_percent_check_spec import (
        ColumnIntegerInRangePercentCheckSpec,
    )
    from ..models.column_invalid_latitude_count_check_spec import (
        ColumnInvalidLatitudeCountCheckSpec,
    )
    from ..models.column_invalid_longitude_count_check_spec import (
        ColumnInvalidLongitudeCountCheckSpec,
    )
    from ..models.column_max_in_range_check_spec import ColumnMaxInRangeCheckSpec
    from ..models.column_mean_in_range_check_spec import ColumnMeanInRangeCheckSpec
    from ..models.column_median_in_range_check_spec import ColumnMedianInRangeCheckSpec
    from ..models.column_min_in_range_check_spec import ColumnMinInRangeCheckSpec
    from ..models.column_negative_count_check_spec import ColumnNegativeCountCheckSpec
    from ..models.column_negative_percent_check_spec import (
        ColumnNegativePercentCheckSpec,
    )
    from ..models.column_non_negative_count_check_spec import (
        ColumnNonNegativeCountCheckSpec,
    )
    from ..models.column_non_negative_percent_check_spec import (
        ColumnNonNegativePercentCheckSpec,
    )
    from ..models.column_number_above_max_value_check_spec import (
        ColumnNumberAboveMaxValueCheckSpec,
    )
    from ..models.column_number_above_max_value_percent_check_spec import (
        ColumnNumberAboveMaxValuePercentCheckSpec,
    )
    from ..models.column_number_below_min_value_check_spec import (
        ColumnNumberBelowMinValueCheckSpec,
    )
    from ..models.column_number_below_min_value_percent_check_spec import (
        ColumnNumberBelowMinValuePercentCheckSpec,
    )
    from ..models.column_number_in_range_percent_check_spec import (
        ColumnNumberInRangePercentCheckSpec,
    )
    from ..models.column_numeric_monthly_monitoring_checks_spec_custom_checks import (
        ColumnNumericMonthlyMonitoringChecksSpecCustomChecks,
    )
    from ..models.column_percentile_10_in_range_check_spec import (
        ColumnPercentile10InRangeCheckSpec,
    )
    from ..models.column_percentile_25_in_range_check_spec import (
        ColumnPercentile25InRangeCheckSpec,
    )
    from ..models.column_percentile_75_in_range_check_spec import (
        ColumnPercentile75InRangeCheckSpec,
    )
    from ..models.column_percentile_90_in_range_check_spec import (
        ColumnPercentile90InRangeCheckSpec,
    )
    from ..models.column_percentile_in_range_check_spec import (
        ColumnPercentileInRangeCheckSpec,
    )
    from ..models.column_population_stddev_in_range_check_spec import (
        ColumnPopulationStddevInRangeCheckSpec,
    )
    from ..models.column_population_variance_in_range_check_spec import (
        ColumnPopulationVarianceInRangeCheckSpec,
    )
    from ..models.column_sample_stddev_in_range_check_spec import (
        ColumnSampleStddevInRangeCheckSpec,
    )
    from ..models.column_sample_variance_in_range_check_spec import (
        ColumnSampleVarianceInRangeCheckSpec,
    )
    from ..models.column_sum_in_range_check_spec import ColumnSumInRangeCheckSpec
    from ..models.column_valid_latitude_percent_check_spec import (
        ColumnValidLatitudePercentCheckSpec,
    )
    from ..models.column_valid_longitude_percent_check_spec import (
        ColumnValidLongitudePercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnNumericMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnNumericMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnNumericMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        monthly_number_below_min_value (Union[Unset, ColumnNumberBelowMinValueCheckSpec]):
        monthly_number_above_max_value (Union[Unset, ColumnNumberAboveMaxValueCheckSpec]):
        monthly_negative_values (Union[Unset, ColumnNegativeCountCheckSpec]):
        monthly_negative_values_percent (Union[Unset, ColumnNegativePercentCheckSpec]):
        monthly_number_below_min_value_percent (Union[Unset, ColumnNumberBelowMinValuePercentCheckSpec]):
        monthly_number_above_max_value_percent (Union[Unset, ColumnNumberAboveMaxValuePercentCheckSpec]):
        monthly_number_in_range_percent (Union[Unset, ColumnNumberInRangePercentCheckSpec]):
        monthly_integer_in_range_percent (Union[Unset, ColumnIntegerInRangePercentCheckSpec]):
        monthly_min_in_range (Union[Unset, ColumnMinInRangeCheckSpec]):
        monthly_max_in_range (Union[Unset, ColumnMaxInRangeCheckSpec]):
        monthly_sum_in_range (Union[Unset, ColumnSumInRangeCheckSpec]):
        monthly_mean_in_range (Union[Unset, ColumnMeanInRangeCheckSpec]):
        monthly_median_in_range (Union[Unset, ColumnMedianInRangeCheckSpec]):
        monthly_percentile_in_range (Union[Unset, ColumnPercentileInRangeCheckSpec]):
        monthly_percentile_10_in_range (Union[Unset, ColumnPercentile10InRangeCheckSpec]):
        monthly_percentile_25_in_range (Union[Unset, ColumnPercentile25InRangeCheckSpec]):
        monthly_percentile_75_in_range (Union[Unset, ColumnPercentile75InRangeCheckSpec]):
        monthly_percentile_90_in_range (Union[Unset, ColumnPercentile90InRangeCheckSpec]):
        monthly_sample_stddev_in_range (Union[Unset, ColumnSampleStddevInRangeCheckSpec]):
        monthly_population_stddev_in_range (Union[Unset, ColumnPopulationStddevInRangeCheckSpec]):
        monthly_sample_variance_in_range (Union[Unset, ColumnSampleVarianceInRangeCheckSpec]):
        monthly_population_variance_in_range (Union[Unset, ColumnPopulationVarianceInRangeCheckSpec]):
        monthly_invalid_latitude (Union[Unset, ColumnInvalidLatitudeCountCheckSpec]):
        monthly_valid_latitude_percent (Union[Unset, ColumnValidLatitudePercentCheckSpec]):
        monthly_invalid_longitude (Union[Unset, ColumnInvalidLongitudeCountCheckSpec]):
        monthly_valid_longitude_percent (Union[Unset, ColumnValidLongitudePercentCheckSpec]):
        monthly_non_negative_values (Union[Unset, ColumnNonNegativeCountCheckSpec]):
        monthly_non_negative_values_percent (Union[Unset, ColumnNonNegativePercentCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnNumericMonthlyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    monthly_number_below_min_value: Union[
        Unset, "ColumnNumberBelowMinValueCheckSpec"
    ] = UNSET
    monthly_number_above_max_value: Union[
        Unset, "ColumnNumberAboveMaxValueCheckSpec"
    ] = UNSET
    monthly_negative_values: Union[Unset, "ColumnNegativeCountCheckSpec"] = UNSET
    monthly_negative_values_percent: Union[Unset, "ColumnNegativePercentCheckSpec"] = (
        UNSET
    )
    monthly_number_below_min_value_percent: Union[
        Unset, "ColumnNumberBelowMinValuePercentCheckSpec"
    ] = UNSET
    monthly_number_above_max_value_percent: Union[
        Unset, "ColumnNumberAboveMaxValuePercentCheckSpec"
    ] = UNSET
    monthly_number_in_range_percent: Union[
        Unset, "ColumnNumberInRangePercentCheckSpec"
    ] = UNSET
    monthly_integer_in_range_percent: Union[
        Unset, "ColumnIntegerInRangePercentCheckSpec"
    ] = UNSET
    monthly_min_in_range: Union[Unset, "ColumnMinInRangeCheckSpec"] = UNSET
    monthly_max_in_range: Union[Unset, "ColumnMaxInRangeCheckSpec"] = UNSET
    monthly_sum_in_range: Union[Unset, "ColumnSumInRangeCheckSpec"] = UNSET
    monthly_mean_in_range: Union[Unset, "ColumnMeanInRangeCheckSpec"] = UNSET
    monthly_median_in_range: Union[Unset, "ColumnMedianInRangeCheckSpec"] = UNSET
    monthly_percentile_in_range: Union[Unset, "ColumnPercentileInRangeCheckSpec"] = (
        UNSET
    )
    monthly_percentile_10_in_range: Union[
        Unset, "ColumnPercentile10InRangeCheckSpec"
    ] = UNSET
    monthly_percentile_25_in_range: Union[
        Unset, "ColumnPercentile25InRangeCheckSpec"
    ] = UNSET
    monthly_percentile_75_in_range: Union[
        Unset, "ColumnPercentile75InRangeCheckSpec"
    ] = UNSET
    monthly_percentile_90_in_range: Union[
        Unset, "ColumnPercentile90InRangeCheckSpec"
    ] = UNSET
    monthly_sample_stddev_in_range: Union[
        Unset, "ColumnSampleStddevInRangeCheckSpec"
    ] = UNSET
    monthly_population_stddev_in_range: Union[
        Unset, "ColumnPopulationStddevInRangeCheckSpec"
    ] = UNSET
    monthly_sample_variance_in_range: Union[
        Unset, "ColumnSampleVarianceInRangeCheckSpec"
    ] = UNSET
    monthly_population_variance_in_range: Union[
        Unset, "ColumnPopulationVarianceInRangeCheckSpec"
    ] = UNSET
    monthly_invalid_latitude: Union[Unset, "ColumnInvalidLatitudeCountCheckSpec"] = (
        UNSET
    )
    monthly_valid_latitude_percent: Union[
        Unset, "ColumnValidLatitudePercentCheckSpec"
    ] = UNSET
    monthly_invalid_longitude: Union[Unset, "ColumnInvalidLongitudeCountCheckSpec"] = (
        UNSET
    )
    monthly_valid_longitude_percent: Union[
        Unset, "ColumnValidLongitudePercentCheckSpec"
    ] = UNSET
    monthly_non_negative_values: Union[Unset, "ColumnNonNegativeCountCheckSpec"] = UNSET
    monthly_non_negative_values_percent: Union[
        Unset, "ColumnNonNegativePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        monthly_number_below_min_value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_number_below_min_value, Unset):
            monthly_number_below_min_value = (
                self.monthly_number_below_min_value.to_dict()
            )

        monthly_number_above_max_value: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_number_above_max_value, Unset):
            monthly_number_above_max_value = (
                self.monthly_number_above_max_value.to_dict()
            )

        monthly_negative_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_negative_values, Unset):
            monthly_negative_values = self.monthly_negative_values.to_dict()

        monthly_negative_values_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_negative_values_percent, Unset):
            monthly_negative_values_percent = (
                self.monthly_negative_values_percent.to_dict()
            )

        monthly_number_below_min_value_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_number_below_min_value_percent, Unset):
            monthly_number_below_min_value_percent = (
                self.monthly_number_below_min_value_percent.to_dict()
            )

        monthly_number_above_max_value_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_number_above_max_value_percent, Unset):
            monthly_number_above_max_value_percent = (
                self.monthly_number_above_max_value_percent.to_dict()
            )

        monthly_number_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_number_in_range_percent, Unset):
            monthly_number_in_range_percent = (
                self.monthly_number_in_range_percent.to_dict()
            )

        monthly_integer_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_integer_in_range_percent, Unset):
            monthly_integer_in_range_percent = (
                self.monthly_integer_in_range_percent.to_dict()
            )

        monthly_min_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_min_in_range, Unset):
            monthly_min_in_range = self.monthly_min_in_range.to_dict()

        monthly_max_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_max_in_range, Unset):
            monthly_max_in_range = self.monthly_max_in_range.to_dict()

        monthly_sum_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_sum_in_range, Unset):
            monthly_sum_in_range = self.monthly_sum_in_range.to_dict()

        monthly_mean_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_mean_in_range, Unset):
            monthly_mean_in_range = self.monthly_mean_in_range.to_dict()

        monthly_median_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_median_in_range, Unset):
            monthly_median_in_range = self.monthly_median_in_range.to_dict()

        monthly_percentile_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_percentile_in_range, Unset):
            monthly_percentile_in_range = self.monthly_percentile_in_range.to_dict()

        monthly_percentile_10_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_percentile_10_in_range, Unset):
            monthly_percentile_10_in_range = (
                self.monthly_percentile_10_in_range.to_dict()
            )

        monthly_percentile_25_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_percentile_25_in_range, Unset):
            monthly_percentile_25_in_range = (
                self.monthly_percentile_25_in_range.to_dict()
            )

        monthly_percentile_75_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_percentile_75_in_range, Unset):
            monthly_percentile_75_in_range = (
                self.monthly_percentile_75_in_range.to_dict()
            )

        monthly_percentile_90_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_percentile_90_in_range, Unset):
            monthly_percentile_90_in_range = (
                self.monthly_percentile_90_in_range.to_dict()
            )

        monthly_sample_stddev_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_sample_stddev_in_range, Unset):
            monthly_sample_stddev_in_range = (
                self.monthly_sample_stddev_in_range.to_dict()
            )

        monthly_population_stddev_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_population_stddev_in_range, Unset):
            monthly_population_stddev_in_range = (
                self.monthly_population_stddev_in_range.to_dict()
            )

        monthly_sample_variance_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_sample_variance_in_range, Unset):
            monthly_sample_variance_in_range = (
                self.monthly_sample_variance_in_range.to_dict()
            )

        monthly_population_variance_in_range: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_population_variance_in_range, Unset):
            monthly_population_variance_in_range = (
                self.monthly_population_variance_in_range.to_dict()
            )

        monthly_invalid_latitude: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_invalid_latitude, Unset):
            monthly_invalid_latitude = self.monthly_invalid_latitude.to_dict()

        monthly_valid_latitude_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_valid_latitude_percent, Unset):
            monthly_valid_latitude_percent = (
                self.monthly_valid_latitude_percent.to_dict()
            )

        monthly_invalid_longitude: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_invalid_longitude, Unset):
            monthly_invalid_longitude = self.monthly_invalid_longitude.to_dict()

        monthly_valid_longitude_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_valid_longitude_percent, Unset):
            monthly_valid_longitude_percent = (
                self.monthly_valid_longitude_percent.to_dict()
            )

        monthly_non_negative_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_non_negative_values, Unset):
            monthly_non_negative_values = self.monthly_non_negative_values.to_dict()

        monthly_non_negative_values_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_non_negative_values_percent, Unset):
            monthly_non_negative_values_percent = (
                self.monthly_non_negative_values_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if monthly_number_below_min_value is not UNSET:
            field_dict["monthly_number_below_min_value"] = (
                monthly_number_below_min_value
            )
        if monthly_number_above_max_value is not UNSET:
            field_dict["monthly_number_above_max_value"] = (
                monthly_number_above_max_value
            )
        if monthly_negative_values is not UNSET:
            field_dict["monthly_negative_values"] = monthly_negative_values
        if monthly_negative_values_percent is not UNSET:
            field_dict["monthly_negative_values_percent"] = (
                monthly_negative_values_percent
            )
        if monthly_number_below_min_value_percent is not UNSET:
            field_dict["monthly_number_below_min_value_percent"] = (
                monthly_number_below_min_value_percent
            )
        if monthly_number_above_max_value_percent is not UNSET:
            field_dict["monthly_number_above_max_value_percent"] = (
                monthly_number_above_max_value_percent
            )
        if monthly_number_in_range_percent is not UNSET:
            field_dict["monthly_number_in_range_percent"] = (
                monthly_number_in_range_percent
            )
        if monthly_integer_in_range_percent is not UNSET:
            field_dict["monthly_integer_in_range_percent"] = (
                monthly_integer_in_range_percent
            )
        if monthly_min_in_range is not UNSET:
            field_dict["monthly_min_in_range"] = monthly_min_in_range
        if monthly_max_in_range is not UNSET:
            field_dict["monthly_max_in_range"] = monthly_max_in_range
        if monthly_sum_in_range is not UNSET:
            field_dict["monthly_sum_in_range"] = monthly_sum_in_range
        if monthly_mean_in_range is not UNSET:
            field_dict["monthly_mean_in_range"] = monthly_mean_in_range
        if monthly_median_in_range is not UNSET:
            field_dict["monthly_median_in_range"] = monthly_median_in_range
        if monthly_percentile_in_range is not UNSET:
            field_dict["monthly_percentile_in_range"] = monthly_percentile_in_range
        if monthly_percentile_10_in_range is not UNSET:
            field_dict["monthly_percentile_10_in_range"] = (
                monthly_percentile_10_in_range
            )
        if monthly_percentile_25_in_range is not UNSET:
            field_dict["monthly_percentile_25_in_range"] = (
                monthly_percentile_25_in_range
            )
        if monthly_percentile_75_in_range is not UNSET:
            field_dict["monthly_percentile_75_in_range"] = (
                monthly_percentile_75_in_range
            )
        if monthly_percentile_90_in_range is not UNSET:
            field_dict["monthly_percentile_90_in_range"] = (
                monthly_percentile_90_in_range
            )
        if monthly_sample_stddev_in_range is not UNSET:
            field_dict["monthly_sample_stddev_in_range"] = (
                monthly_sample_stddev_in_range
            )
        if monthly_population_stddev_in_range is not UNSET:
            field_dict["monthly_population_stddev_in_range"] = (
                monthly_population_stddev_in_range
            )
        if monthly_sample_variance_in_range is not UNSET:
            field_dict["monthly_sample_variance_in_range"] = (
                monthly_sample_variance_in_range
            )
        if monthly_population_variance_in_range is not UNSET:
            field_dict["monthly_population_variance_in_range"] = (
                monthly_population_variance_in_range
            )
        if monthly_invalid_latitude is not UNSET:
            field_dict["monthly_invalid_latitude"] = monthly_invalid_latitude
        if monthly_valid_latitude_percent is not UNSET:
            field_dict["monthly_valid_latitude_percent"] = (
                monthly_valid_latitude_percent
            )
        if monthly_invalid_longitude is not UNSET:
            field_dict["monthly_invalid_longitude"] = monthly_invalid_longitude
        if monthly_valid_longitude_percent is not UNSET:
            field_dict["monthly_valid_longitude_percent"] = (
                monthly_valid_longitude_percent
            )
        if monthly_non_negative_values is not UNSET:
            field_dict["monthly_non_negative_values"] = monthly_non_negative_values
        if monthly_non_negative_values_percent is not UNSET:
            field_dict["monthly_non_negative_values_percent"] = (
                monthly_non_negative_values_percent
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_integer_in_range_percent_check_spec import (
            ColumnIntegerInRangePercentCheckSpec,
        )
        from ..models.column_invalid_latitude_count_check_spec import (
            ColumnInvalidLatitudeCountCheckSpec,
        )
        from ..models.column_invalid_longitude_count_check_spec import (
            ColumnInvalidLongitudeCountCheckSpec,
        )
        from ..models.column_max_in_range_check_spec import ColumnMaxInRangeCheckSpec
        from ..models.column_mean_in_range_check_spec import ColumnMeanInRangeCheckSpec
        from ..models.column_median_in_range_check_spec import (
            ColumnMedianInRangeCheckSpec,
        )
        from ..models.column_min_in_range_check_spec import ColumnMinInRangeCheckSpec
        from ..models.column_negative_count_check_spec import (
            ColumnNegativeCountCheckSpec,
        )
        from ..models.column_negative_percent_check_spec import (
            ColumnNegativePercentCheckSpec,
        )
        from ..models.column_non_negative_count_check_spec import (
            ColumnNonNegativeCountCheckSpec,
        )
        from ..models.column_non_negative_percent_check_spec import (
            ColumnNonNegativePercentCheckSpec,
        )
        from ..models.column_number_above_max_value_check_spec import (
            ColumnNumberAboveMaxValueCheckSpec,
        )
        from ..models.column_number_above_max_value_percent_check_spec import (
            ColumnNumberAboveMaxValuePercentCheckSpec,
        )
        from ..models.column_number_below_min_value_check_spec import (
            ColumnNumberBelowMinValueCheckSpec,
        )
        from ..models.column_number_below_min_value_percent_check_spec import (
            ColumnNumberBelowMinValuePercentCheckSpec,
        )
        from ..models.column_number_in_range_percent_check_spec import (
            ColumnNumberInRangePercentCheckSpec,
        )
        from ..models.column_numeric_monthly_monitoring_checks_spec_custom_checks import (
            ColumnNumericMonthlyMonitoringChecksSpecCustomChecks,
        )
        from ..models.column_percentile_10_in_range_check_spec import (
            ColumnPercentile10InRangeCheckSpec,
        )
        from ..models.column_percentile_25_in_range_check_spec import (
            ColumnPercentile25InRangeCheckSpec,
        )
        from ..models.column_percentile_75_in_range_check_spec import (
            ColumnPercentile75InRangeCheckSpec,
        )
        from ..models.column_percentile_90_in_range_check_spec import (
            ColumnPercentile90InRangeCheckSpec,
        )
        from ..models.column_percentile_in_range_check_spec import (
            ColumnPercentileInRangeCheckSpec,
        )
        from ..models.column_population_stddev_in_range_check_spec import (
            ColumnPopulationStddevInRangeCheckSpec,
        )
        from ..models.column_population_variance_in_range_check_spec import (
            ColumnPopulationVarianceInRangeCheckSpec,
        )
        from ..models.column_sample_stddev_in_range_check_spec import (
            ColumnSampleStddevInRangeCheckSpec,
        )
        from ..models.column_sample_variance_in_range_check_spec import (
            ColumnSampleVarianceInRangeCheckSpec,
        )
        from ..models.column_sum_in_range_check_spec import ColumnSumInRangeCheckSpec
        from ..models.column_valid_latitude_percent_check_spec import (
            ColumnValidLatitudePercentCheckSpec,
        )
        from ..models.column_valid_longitude_percent_check_spec import (
            ColumnValidLongitudePercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnNumericMonthlyMonitoringChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnNumericMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        _monthly_number_below_min_value = d.pop("monthly_number_below_min_value", UNSET)
        monthly_number_below_min_value: Union[Unset, ColumnNumberBelowMinValueCheckSpec]
        if isinstance(_monthly_number_below_min_value, Unset):
            monthly_number_below_min_value = UNSET
        else:
            monthly_number_below_min_value = (
                ColumnNumberBelowMinValueCheckSpec.from_dict(
                    _monthly_number_below_min_value
                )
            )

        _monthly_number_above_max_value = d.pop("monthly_number_above_max_value", UNSET)
        monthly_number_above_max_value: Union[Unset, ColumnNumberAboveMaxValueCheckSpec]
        if isinstance(_monthly_number_above_max_value, Unset):
            monthly_number_above_max_value = UNSET
        else:
            monthly_number_above_max_value = (
                ColumnNumberAboveMaxValueCheckSpec.from_dict(
                    _monthly_number_above_max_value
                )
            )

        _monthly_negative_values = d.pop("monthly_negative_values", UNSET)
        monthly_negative_values: Union[Unset, ColumnNegativeCountCheckSpec]
        if isinstance(_monthly_negative_values, Unset):
            monthly_negative_values = UNSET
        else:
            monthly_negative_values = ColumnNegativeCountCheckSpec.from_dict(
                _monthly_negative_values
            )

        _monthly_negative_values_percent = d.pop(
            "monthly_negative_values_percent", UNSET
        )
        monthly_negative_values_percent: Union[Unset, ColumnNegativePercentCheckSpec]
        if isinstance(_monthly_negative_values_percent, Unset):
            monthly_negative_values_percent = UNSET
        else:
            monthly_negative_values_percent = ColumnNegativePercentCheckSpec.from_dict(
                _monthly_negative_values_percent
            )

        _monthly_number_below_min_value_percent = d.pop(
            "monthly_number_below_min_value_percent", UNSET
        )
        monthly_number_below_min_value_percent: Union[
            Unset, ColumnNumberBelowMinValuePercentCheckSpec
        ]
        if isinstance(_monthly_number_below_min_value_percent, Unset):
            monthly_number_below_min_value_percent = UNSET
        else:
            monthly_number_below_min_value_percent = (
                ColumnNumberBelowMinValuePercentCheckSpec.from_dict(
                    _monthly_number_below_min_value_percent
                )
            )

        _monthly_number_above_max_value_percent = d.pop(
            "monthly_number_above_max_value_percent", UNSET
        )
        monthly_number_above_max_value_percent: Union[
            Unset, ColumnNumberAboveMaxValuePercentCheckSpec
        ]
        if isinstance(_monthly_number_above_max_value_percent, Unset):
            monthly_number_above_max_value_percent = UNSET
        else:
            monthly_number_above_max_value_percent = (
                ColumnNumberAboveMaxValuePercentCheckSpec.from_dict(
                    _monthly_number_above_max_value_percent
                )
            )

        _monthly_number_in_range_percent = d.pop(
            "monthly_number_in_range_percent", UNSET
        )
        monthly_number_in_range_percent: Union[
            Unset, ColumnNumberInRangePercentCheckSpec
        ]
        if isinstance(_monthly_number_in_range_percent, Unset):
            monthly_number_in_range_percent = UNSET
        else:
            monthly_number_in_range_percent = (
                ColumnNumberInRangePercentCheckSpec.from_dict(
                    _monthly_number_in_range_percent
                )
            )

        _monthly_integer_in_range_percent = d.pop(
            "monthly_integer_in_range_percent", UNSET
        )
        monthly_integer_in_range_percent: Union[
            Unset, ColumnIntegerInRangePercentCheckSpec
        ]
        if isinstance(_monthly_integer_in_range_percent, Unset):
            monthly_integer_in_range_percent = UNSET
        else:
            monthly_integer_in_range_percent = (
                ColumnIntegerInRangePercentCheckSpec.from_dict(
                    _monthly_integer_in_range_percent
                )
            )

        _monthly_min_in_range = d.pop("monthly_min_in_range", UNSET)
        monthly_min_in_range: Union[Unset, ColumnMinInRangeCheckSpec]
        if isinstance(_monthly_min_in_range, Unset):
            monthly_min_in_range = UNSET
        else:
            monthly_min_in_range = ColumnMinInRangeCheckSpec.from_dict(
                _monthly_min_in_range
            )

        _monthly_max_in_range = d.pop("monthly_max_in_range", UNSET)
        monthly_max_in_range: Union[Unset, ColumnMaxInRangeCheckSpec]
        if isinstance(_monthly_max_in_range, Unset):
            monthly_max_in_range = UNSET
        else:
            monthly_max_in_range = ColumnMaxInRangeCheckSpec.from_dict(
                _monthly_max_in_range
            )

        _monthly_sum_in_range = d.pop("monthly_sum_in_range", UNSET)
        monthly_sum_in_range: Union[Unset, ColumnSumInRangeCheckSpec]
        if isinstance(_monthly_sum_in_range, Unset):
            monthly_sum_in_range = UNSET
        else:
            monthly_sum_in_range = ColumnSumInRangeCheckSpec.from_dict(
                _monthly_sum_in_range
            )

        _monthly_mean_in_range = d.pop("monthly_mean_in_range", UNSET)
        monthly_mean_in_range: Union[Unset, ColumnMeanInRangeCheckSpec]
        if isinstance(_monthly_mean_in_range, Unset):
            monthly_mean_in_range = UNSET
        else:
            monthly_mean_in_range = ColumnMeanInRangeCheckSpec.from_dict(
                _monthly_mean_in_range
            )

        _monthly_median_in_range = d.pop("monthly_median_in_range", UNSET)
        monthly_median_in_range: Union[Unset, ColumnMedianInRangeCheckSpec]
        if isinstance(_monthly_median_in_range, Unset):
            monthly_median_in_range = UNSET
        else:
            monthly_median_in_range = ColumnMedianInRangeCheckSpec.from_dict(
                _monthly_median_in_range
            )

        _monthly_percentile_in_range = d.pop("monthly_percentile_in_range", UNSET)
        monthly_percentile_in_range: Union[Unset, ColumnPercentileInRangeCheckSpec]
        if isinstance(_monthly_percentile_in_range, Unset):
            monthly_percentile_in_range = UNSET
        else:
            monthly_percentile_in_range = ColumnPercentileInRangeCheckSpec.from_dict(
                _monthly_percentile_in_range
            )

        _monthly_percentile_10_in_range = d.pop("monthly_percentile_10_in_range", UNSET)
        monthly_percentile_10_in_range: Union[Unset, ColumnPercentile10InRangeCheckSpec]
        if isinstance(_monthly_percentile_10_in_range, Unset):
            monthly_percentile_10_in_range = UNSET
        else:
            monthly_percentile_10_in_range = (
                ColumnPercentile10InRangeCheckSpec.from_dict(
                    _monthly_percentile_10_in_range
                )
            )

        _monthly_percentile_25_in_range = d.pop("monthly_percentile_25_in_range", UNSET)
        monthly_percentile_25_in_range: Union[Unset, ColumnPercentile25InRangeCheckSpec]
        if isinstance(_monthly_percentile_25_in_range, Unset):
            monthly_percentile_25_in_range = UNSET
        else:
            monthly_percentile_25_in_range = (
                ColumnPercentile25InRangeCheckSpec.from_dict(
                    _monthly_percentile_25_in_range
                )
            )

        _monthly_percentile_75_in_range = d.pop("monthly_percentile_75_in_range", UNSET)
        monthly_percentile_75_in_range: Union[Unset, ColumnPercentile75InRangeCheckSpec]
        if isinstance(_monthly_percentile_75_in_range, Unset):
            monthly_percentile_75_in_range = UNSET
        else:
            monthly_percentile_75_in_range = (
                ColumnPercentile75InRangeCheckSpec.from_dict(
                    _monthly_percentile_75_in_range
                )
            )

        _monthly_percentile_90_in_range = d.pop("monthly_percentile_90_in_range", UNSET)
        monthly_percentile_90_in_range: Union[Unset, ColumnPercentile90InRangeCheckSpec]
        if isinstance(_monthly_percentile_90_in_range, Unset):
            monthly_percentile_90_in_range = UNSET
        else:
            monthly_percentile_90_in_range = (
                ColumnPercentile90InRangeCheckSpec.from_dict(
                    _monthly_percentile_90_in_range
                )
            )

        _monthly_sample_stddev_in_range = d.pop("monthly_sample_stddev_in_range", UNSET)
        monthly_sample_stddev_in_range: Union[Unset, ColumnSampleStddevInRangeCheckSpec]
        if isinstance(_monthly_sample_stddev_in_range, Unset):
            monthly_sample_stddev_in_range = UNSET
        else:
            monthly_sample_stddev_in_range = (
                ColumnSampleStddevInRangeCheckSpec.from_dict(
                    _monthly_sample_stddev_in_range
                )
            )

        _monthly_population_stddev_in_range = d.pop(
            "monthly_population_stddev_in_range", UNSET
        )
        monthly_population_stddev_in_range: Union[
            Unset, ColumnPopulationStddevInRangeCheckSpec
        ]
        if isinstance(_monthly_population_stddev_in_range, Unset):
            monthly_population_stddev_in_range = UNSET
        else:
            monthly_population_stddev_in_range = (
                ColumnPopulationStddevInRangeCheckSpec.from_dict(
                    _monthly_population_stddev_in_range
                )
            )

        _monthly_sample_variance_in_range = d.pop(
            "monthly_sample_variance_in_range", UNSET
        )
        monthly_sample_variance_in_range: Union[
            Unset, ColumnSampleVarianceInRangeCheckSpec
        ]
        if isinstance(_monthly_sample_variance_in_range, Unset):
            monthly_sample_variance_in_range = UNSET
        else:
            monthly_sample_variance_in_range = (
                ColumnSampleVarianceInRangeCheckSpec.from_dict(
                    _monthly_sample_variance_in_range
                )
            )

        _monthly_population_variance_in_range = d.pop(
            "monthly_population_variance_in_range", UNSET
        )
        monthly_population_variance_in_range: Union[
            Unset, ColumnPopulationVarianceInRangeCheckSpec
        ]
        if isinstance(_monthly_population_variance_in_range, Unset):
            monthly_population_variance_in_range = UNSET
        else:
            monthly_population_variance_in_range = (
                ColumnPopulationVarianceInRangeCheckSpec.from_dict(
                    _monthly_population_variance_in_range
                )
            )

        _monthly_invalid_latitude = d.pop("monthly_invalid_latitude", UNSET)
        monthly_invalid_latitude: Union[Unset, ColumnInvalidLatitudeCountCheckSpec]
        if isinstance(_monthly_invalid_latitude, Unset):
            monthly_invalid_latitude = UNSET
        else:
            monthly_invalid_latitude = ColumnInvalidLatitudeCountCheckSpec.from_dict(
                _monthly_invalid_latitude
            )

        _monthly_valid_latitude_percent = d.pop("monthly_valid_latitude_percent", UNSET)
        monthly_valid_latitude_percent: Union[
            Unset, ColumnValidLatitudePercentCheckSpec
        ]
        if isinstance(_monthly_valid_latitude_percent, Unset):
            monthly_valid_latitude_percent = UNSET
        else:
            monthly_valid_latitude_percent = (
                ColumnValidLatitudePercentCheckSpec.from_dict(
                    _monthly_valid_latitude_percent
                )
            )

        _monthly_invalid_longitude = d.pop("monthly_invalid_longitude", UNSET)
        monthly_invalid_longitude: Union[Unset, ColumnInvalidLongitudeCountCheckSpec]
        if isinstance(_monthly_invalid_longitude, Unset):
            monthly_invalid_longitude = UNSET
        else:
            monthly_invalid_longitude = ColumnInvalidLongitudeCountCheckSpec.from_dict(
                _monthly_invalid_longitude
            )

        _monthly_valid_longitude_percent = d.pop(
            "monthly_valid_longitude_percent", UNSET
        )
        monthly_valid_longitude_percent: Union[
            Unset, ColumnValidLongitudePercentCheckSpec
        ]
        if isinstance(_monthly_valid_longitude_percent, Unset):
            monthly_valid_longitude_percent = UNSET
        else:
            monthly_valid_longitude_percent = (
                ColumnValidLongitudePercentCheckSpec.from_dict(
                    _monthly_valid_longitude_percent
                )
            )

        _monthly_non_negative_values = d.pop("monthly_non_negative_values", UNSET)
        monthly_non_negative_values: Union[Unset, ColumnNonNegativeCountCheckSpec]
        if isinstance(_monthly_non_negative_values, Unset):
            monthly_non_negative_values = UNSET
        else:
            monthly_non_negative_values = ColumnNonNegativeCountCheckSpec.from_dict(
                _monthly_non_negative_values
            )

        _monthly_non_negative_values_percent = d.pop(
            "monthly_non_negative_values_percent", UNSET
        )
        monthly_non_negative_values_percent: Union[
            Unset, ColumnNonNegativePercentCheckSpec
        ]
        if isinstance(_monthly_non_negative_values_percent, Unset):
            monthly_non_negative_values_percent = UNSET
        else:
            monthly_non_negative_values_percent = (
                ColumnNonNegativePercentCheckSpec.from_dict(
                    _monthly_non_negative_values_percent
                )
            )

        column_numeric_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            monthly_number_below_min_value=monthly_number_below_min_value,
            monthly_number_above_max_value=monthly_number_above_max_value,
            monthly_negative_values=monthly_negative_values,
            monthly_negative_values_percent=monthly_negative_values_percent,
            monthly_number_below_min_value_percent=monthly_number_below_min_value_percent,
            monthly_number_above_max_value_percent=monthly_number_above_max_value_percent,
            monthly_number_in_range_percent=monthly_number_in_range_percent,
            monthly_integer_in_range_percent=monthly_integer_in_range_percent,
            monthly_min_in_range=monthly_min_in_range,
            monthly_max_in_range=monthly_max_in_range,
            monthly_sum_in_range=monthly_sum_in_range,
            monthly_mean_in_range=monthly_mean_in_range,
            monthly_median_in_range=monthly_median_in_range,
            monthly_percentile_in_range=monthly_percentile_in_range,
            monthly_percentile_10_in_range=monthly_percentile_10_in_range,
            monthly_percentile_25_in_range=monthly_percentile_25_in_range,
            monthly_percentile_75_in_range=monthly_percentile_75_in_range,
            monthly_percentile_90_in_range=monthly_percentile_90_in_range,
            monthly_sample_stddev_in_range=monthly_sample_stddev_in_range,
            monthly_population_stddev_in_range=monthly_population_stddev_in_range,
            monthly_sample_variance_in_range=monthly_sample_variance_in_range,
            monthly_population_variance_in_range=monthly_population_variance_in_range,
            monthly_invalid_latitude=monthly_invalid_latitude,
            monthly_valid_latitude_percent=monthly_valid_latitude_percent,
            monthly_invalid_longitude=monthly_invalid_longitude,
            monthly_valid_longitude_percent=monthly_valid_longitude_percent,
            monthly_non_negative_values=monthly_non_negative_values,
            monthly_non_negative_values_percent=monthly_non_negative_values_percent,
        )

        column_numeric_monthly_monitoring_checks_spec.additional_properties = d
        return column_numeric_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dashboard_spec_parameters import DashboardSpecParameters


T = TypeVar("T", bound="DashboardSpec")


@_attrs_define
class DashboardSpec:
    """
    Attributes:
        dashboard_name (Union[Unset, str]): Dashboard name
        url (Union[Unset, str]): Dashboard url
        width (Union[Unset, int]): Dashboard width (px)
        height (Union[Unset, int]): Dashboard height (px)
        standard (Union[Unset, bool]): Shows the dashboard always in the data quality dashboard section. The dashboards
            that are not 'standard' are advanced dashboards, hidden initially.
        disable_thumbnail (Union[Unset, bool]): Disables showing a thumbnail. A thumbnail url for Looker Studio
            dashboards is generated by adding /thumbnail to the end of the dashboard's url. It is a Google generated
            thumbnail of the dashboard.
        parameters (Union[Unset, DashboardSpecParameters]): Key/value dictionary of additional parameters to be passed
            to the dashboard
    """

    dashboard_name: Union[Unset, str] = UNSET
    url: Union[Unset, str] = UNSET
    width: Union[Unset, int] = UNSET
    height: Union[Unset, int] = UNSET
    standard: Union[Unset, bool] = UNSET
    disable_thumbnail: Union[Unset, bool] = UNSET
    parameters: Union[Unset, "DashboardSpecParameters"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        dashboard_name = self.dashboard_name
        url = self.url
        width = self.width
        height = self.height
        standard = self.standard
        disable_thumbnail = self.disable_thumbnail
        parameters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.parameters, Unset):
            parameters = self.parameters.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if dashboard_name is not UNSET:
            field_dict["dashboard_name"] = dashboard_name
        if url is not UNSET:
            field_dict["url"] = url
        if width is not UNSET:
            field_dict["width"] = width
        if height is not UNSET:
            field_dict["height"] = height
        if standard is not UNSET:
            field_dict["standard"] = standard
        if disable_thumbnail is not UNSET:
            field_dict["disable_thumbnail"] = disable_thumbnail
        if parameters is not UNSET:
            field_dict["parameters"] = parameters

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dashboard_spec_parameters import DashboardSpecParameters

        d = src_dict.copy()
        dashboard_name = d.pop("dashboard_name", UNSET)

        url = d.pop("url", UNSET)

        width = d.pop("width", UNSET)

        height = d.pop("height", UNSET)

        standard = d.pop("standard", UNSET)

        disable_thumbnail = d.pop("disable_thumbnail", UNSET)

        _parameters = d.pop("parameters", UNSET)
        parameters: Union[Unset, DashboardSpecParameters]
        if isinstance(_parameters, Unset):
            parameters = UNSET
        else:
            parameters = DashboardSpecParameters.from_dict(_parameters)

        dashboard_spec = cls(
            dashboard_name=dashboard_name,
            url=url,
            width=width,
            height=height,
            standard=standard,
            disable_thumbnail=disable_thumbnail,
            parameters=parameters,
        )

        dashboard_spec.additional_properties = d
        return dashboard_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class IncidentGroupingLevel(str, Enum):
    TABLE = "table"
    TABLE_DIMENSION = "table_dimension"
    TABLE_DIMENSION_CATEGORY = "table_dimension_category"
    TABLE_DIMENSION_CATEGORY_NAME = "table_dimension_category_name"
    TABLE_DIMENSION_CATEGORY_TYPE = "table_dimension_category_type"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.rule_severity_level import RuleSeverityLevel
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_current_data_quality_status_model_checks import (
        TableCurrentDataQualityStatusModelChecks,
    )
    from ..models.table_current_data_quality_status_model_columns import (
        TableCurrentDataQualityStatusModelColumns,
    )
    from ..models.table_current_data_quality_status_model_dimensions import (
        TableCurrentDataQualityStatusModelDimensions,
    )


T = TypeVar("T", bound="TableCurrentDataQualityStatusModel")


@_attrs_define
class TableCurrentDataQualityStatusModel:
    """The table's most recent data quality status. It is a summary of the results of the most recently executed data
    quality checks on the table. Verify the value of the highest_severity_level to see if there are any data quality
    issues on the table. The values of severity levels are: 0 - all data quality checks passed, 1 - a warning was
    detected, 2 - an error was detected, 3 - a fatal data quality issue was detected.

        Attributes:
            data_domain (Union[Unset, str]): Data domain name.
            connection_name (Union[Unset, str]): The connection name in DQOps.
            schema_name (Union[Unset, str]): The schema name.
            table_name (Union[Unset, str]): The table name.
            total_row_count (Union[Unset, int]): Most recent row count. Returned only when the status of the monitoring or
                profiling checks was requested.
            data_freshness_delay_days (Union[Unset, float]): The last measured data freshness delay in days. Requires any of
                the data freshness checks in the monitoring section configured and up to date.
            current_severity (Union[Unset, RuleSeverityLevel]):
            highest_historical_severity (Union[Unset, RuleSeverityLevel]):
            last_check_executed_at (Union[Unset, int]): The UTC timestamp when the most recent data quality check was
                executed on the table.
            executed_checks (Union[Unset, int]): The total number of most recent checks that were executed on the table.
                Table comparison checks that are comparing groups of data are counted as the number of compared data groups.
            valid_results (Union[Unset, int]): The number of most recent valid data quality checks that passed without
                raising any issues.
            warnings (Union[Unset, int]): The number of most recent data quality checks that failed by raising a warning
                severity data quality issue.
            errors (Union[Unset, int]): The number of most recent data quality checks that failed by raising an error
                severity data quality issue.
            fatals (Union[Unset, int]): The number of most recent data quality checks that failed by raising a fatal
                severity data quality issue.
            execution_errors (Union[Unset, int]): The number of data quality check execution errors that were reported due
                to access issues to the data source, invalid mapping in DQOps, invalid queries in data quality sensors or
                invalid python rules. When an execution error is reported, the configuration of a data quality check on a table
                must be updated.
            data_quality_kpi (Union[Unset, float]): Data quality KPI score for the table, measured as a percentage of passed
                data quality checks. DQOps counts data quality issues at a warning severity level as passed checks. The data
                quality KPI score is a value in the range 0..100.
            checks (Union[Unset, TableCurrentDataQualityStatusModelChecks]): The dictionary of statuses for data quality
                checks. The keys are data quality check names, the values are the current data quality check statuses that
                describe the most current status.
            columns (Union[Unset, TableCurrentDataQualityStatusModelColumns]): Dictionary of data statues for all columns
                that have any known data quality results. The keys in the dictionary are the column names.
            dimensions (Union[Unset, TableCurrentDataQualityStatusModelDimensions]): Dictionary of the current data quality
                statues for each data quality dimension.
            table_exist (Union[Unset, bool]): The flag informing whether the table exist. The table might not exist for the
                imported data lineage source tables.
    """

    data_domain: Union[Unset, str] = UNSET
    connection_name: Union[Unset, str] = UNSET
    schema_name: Union[Unset, str] = UNSET
    table_name: Union[Unset, str] = UNSET
    total_row_count: Union[Unset, int] = UNSET
    data_freshness_delay_days: Union[Unset, float] = UNSET
    current_severity: Union[Unset, RuleSeverityLevel] = UNSET
    highest_historical_severity: Union[Unset, RuleSeverityLevel] = UNSET
    last_check_executed_at: Union[Unset, int] = UNSET
    executed_checks: Union[Unset, int] = UNSET
    valid_results: Union[Unset, int] = UNSET
    warnings: Union[Unset, int] = UNSET
    errors: Union[Unset, int] = UNSET
    fatals: Union[Unset, int] = UNSET
    execution_errors: Union[Unset, int] = UNSET
    data_quality_kpi: Union[Unset, float] = UNSET
    checks: Union[Unset, "TableCurrentDataQualityStatusModelChecks"] = UNSET
    columns: Union[Unset, "TableCurrentDataQualityStatusModelColumns"] = UNSET
    dimensions: Union[Unset, "TableCurrentDataQualityStatusModelDimensions"] = UNSET
    table_exist: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data_domain = self.data_domain
        connection_name = self.connection_name
        schema_name = self.schema_name
        table_name = self.table_name
        total_row_count = self.total_row_count
        data_freshness_delay_days = self.data_freshness_delay_days
        current_severity: Union[Unset, str] = UNSET
        if not isinstance(self.current_severity, Unset):
            current_severity = self.current_severity.value

        highest_historical_severity: Union[Unset, str] = UNSET
        if not isinstance(self.highest_historical_severity, Unset):
            highest_historical_severity = self.highest_historical_severity.value

        last_check_executed_at = self.last_check_executed_at
        executed_checks = self.executed_checks
        valid_results = self.valid_results
        warnings = self.warnings
        errors = self.errors
        fatals = self.fatals
        execution_errors = self.execution_errors
        data_quality_kpi = self.data_quality_kpi
        checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.checks, Unset):
            checks = self.checks.to_dict()

        columns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.columns, Unset):
            columns = self.columns.to_dict()

        dimensions: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.dimensions, Unset):
            dimensions = self.dimensions.to_dict()

        table_exist = self.table_exist

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data_domain is not UNSET:
            field_dict["data_domain"] = data_domain
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if schema_name is not UNSET:
            field_dict["schema_name"] = schema_name
        if table_name is not UNSET:
            field_dict["table_name"] = table_name
        if total_row_count is not UNSET:
            field_dict["total_row_count"] = total_row_count
        if data_freshness_delay_days is not UNSET:
            field_dict["data_freshness_delay_days"] = data_freshness_delay_days
        if current_severity is not UNSET:
            field_dict["current_severity"] = current_severity
        if highest_historical_severity is not UNSET:
            field_dict["highest_historical_severity"] = highest_historical_severity
        if last_check_executed_at is not UNSET:
            field_dict["last_check_executed_at"] = last_check_executed_at
        if executed_checks is not UNSET:
            field_dict["executed_checks"] = executed_checks
        if valid_results is not UNSET:
            field_dict["valid_results"] = valid_results
        if warnings is not UNSET:
            field_dict["warnings"] = warnings
        if errors is not UNSET:
            field_dict["errors"] = errors
        if fatals is not UNSET:
            field_dict["fatals"] = fatals
        if execution_errors is not UNSET:
            field_dict["execution_errors"] = execution_errors
        if data_quality_kpi is not UNSET:
            field_dict["data_quality_kpi"] = data_quality_kpi
        if checks is not UNSET:
            field_dict["checks"] = checks
        if columns is not UNSET:
            field_dict["columns"] = columns
        if dimensions is not UNSET:
            field_dict["dimensions"] = dimensions
        if table_exist is not UNSET:
            field_dict["table_exist"] = table_exist

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_current_data_quality_status_model_checks import (
            TableCurrentDataQualityStatusModelChecks,
        )
        from ..models.table_current_data_quality_status_model_columns import (
            TableCurrentDataQualityStatusModelColumns,
        )
        from ..models.table_current_data_quality_status_model_dimensions import (
            TableCurrentDataQualityStatusModelDimensions,
        )

        d = src_dict.copy()
        data_domain = d.pop("data_domain", UNSET)

        connection_name = d.pop("connection_name", UNSET)

        schema_name = d.pop("schema_name", UNSET)

        table_name = d.pop("table_name", UNSET)

        total_row_count = d.pop("total_row_count", UNSET)

        data_freshness_delay_days = d.pop("data_freshness_delay_days", UNSET)

        _current_severity = d.pop("current_severity", UNSET)
        current_severity: Union[Unset, RuleSeverityLevel]
        if isinstance(_current_severity, Unset):
            current_severity = UNSET
        else:
            current_severity = RuleSeverityLevel(_current_severity)

        _highest_historical_severity = d.pop("highest_historical_severity", UNSET)
        highest_historical_severity: Union[Unset, RuleSeverityLevel]
        if isinstance(_highest_historical_severity, Unset):
            highest_historical_severity = UNSET
        else:
            highest_historical_severity = RuleSeverityLevel(
                _highest_historical_severity
            )

        last_check_executed_at = d.pop("last_check_executed_at", UNSET)

        executed_checks = d.pop("executed_checks", UNSET)

        valid_results = d.pop("valid_results", UNSET)

        warnings = d.pop("warnings", UNSET)

        errors = d.pop("errors", UNSET)

        fatals = d.pop("fatals", UNSET)

        execution_errors = d.pop("execution_errors", UNSET)

        data_quality_kpi = d.pop("data_quality_kpi", UNSET)

        _checks = d.pop("checks", UNSET)
        checks: Union[Unset, TableCurrentDataQualityStatusModelChecks]
        if isinstance(_checks, Unset):
            checks = UNSET
        else:
            checks = TableCurrentDataQualityStatusModelChecks.from_dict(_checks)

        _columns = d.pop("columns", UNSET)
        columns: Union[Unset, TableCurrentDataQualityStatusModelColumns]
        if isinstance(_columns, Unset):
            columns = UNSET
        else:
            columns = TableCurrentDataQualityStatusModelColumns.from_dict(_columns)

        _dimensions = d.pop("dimensions", UNSET)
        dimensions: Union[Unset, TableCurrentDataQualityStatusModelDimensions]
        if isinstance(_dimensions, Unset):
            dimensions = UNSET
        else:
            dimensions = TableCurrentDataQualityStatusModelDimensions.from_dict(
                _dimensions
            )

        table_exist = d.pop("table_exist", UNSET)

        table_current_data_quality_status_model = cls(
            data_domain=data_domain,
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            total_row_count=total_row_count,
            data_freshness_delay_days=data_freshness_delay_days,
            current_severity=current_severity,
            highest_historical_severity=highest_historical_severity,
            last_check_executed_at=last_check_executed_at,
            executed_checks=executed_checks,
            valid_results=valid_results,
            warnings=warnings,
            errors=errors,
            fatals=fatals,
            execution_errors=execution_errors,
            data_quality_kpi=data_quality_kpi,
            checks=checks,
            columns=columns,
            dimensions=dimensions,
            table_exist=table_exist,
        )

        table_current_data_quality_status_model.additional_properties = d
        return table_current_data_quality_status_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar(
    "T", bound="ColumnAccuracyTotalNotNullCountMatchPercentSensorParametersSpec"
)


@_attrs_define
class ColumnAccuracyTotalNotNullCountMatchPercentSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        referenced_table (Union[Unset, str]): The name of the reference table. DQOps accepts the name in two forms: a
            fully qualified name including the schema name, for example landing_zone.customer_raw, or only a table name.
            When only a table name is used, DQOps assumes that the table is in the same schema as the analyzed table, and
            prefixes the name with the schema and optionally database name.
        referenced_column (Union[Unset, str]): The name of a column in the reference table. DQOps calculates an
            aggregate value on that column and compares it with the value in the analyzed table.
    """

    filter_: Union[Unset, str] = UNSET
    referenced_table: Union[Unset, str] = UNSET
    referenced_column: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        referenced_table = self.referenced_table
        referenced_column = self.referenced_column

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if referenced_table is not UNSET:
            field_dict["referenced_table"] = referenced_table
        if referenced_column is not UNSET:
            field_dict["referenced_column"] = referenced_column

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        referenced_table = d.pop("referenced_table", UNSET)

        referenced_column = d.pop("referenced_column", UNSET)

        column_accuracy_total_not_null_count_match_percent_sensor_parameters_spec = cls(
            filter_=filter_,
            referenced_table=referenced_table,
            referenced_column=referenced_column,
        )

        column_accuracy_total_not_null_count_match_percent_sensor_parameters_spec.additional_properties = (
            d
        )
        return column_accuracy_total_not_null_count_match_percent_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_target_model import CheckTargetModel
from ..models.default_rule_severity_level import DefaultRuleSeverityLevel
from ..models.schedule_enabled_status_model import ScheduleEnabledStatusModel
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.check_search_filters import CheckSearchFilters
    from ..models.comment_spec import CommentSpec
    from ..models.cron_schedule_spec import CronScheduleSpec
    from ..models.data_grouping_configuration_spec import DataGroupingConfigurationSpec
    from ..models.delete_stored_data_queue_job_parameters import (
        DeleteStoredDataQueueJobParameters,
    )
    from ..models.effective_schedule_model import EffectiveScheduleModel
    from ..models.field_model import FieldModel
    from ..models.rule_thresholds_model import RuleThresholdsModel
    from ..models.similar_check_model import SimilarCheckModel


T = TypeVar("T", bound="CheckModel")


@_attrs_define
class CheckModel:
    """Model that returns the form definition and the form data to edit a single data quality check.

    Attributes:
        check_name (Union[Unset, str]): Data quality check name that is used in YAML.
        help_text (Union[Unset, str]): Help text that describes the data quality check.
        display_name (Union[Unset, str]): User assigned display name that is shown instead of the original data quality
            check name.
        friendly_name (Union[Unset, str]): An alternative check's name that is shown on the check editor as a hint.
        sensor_parameters (Union[Unset, List['FieldModel']]): List of fields for editing the sensor parameters.
        sensor_name (Union[Unset, str]): Full sensor name. This field is for information purposes and can be used to
            create additional custom checks that reuse the same data quality sensor.
        quality_dimension (Union[Unset, str]): Data quality dimension used for tagging the results of this data quality
            checks.
        rule (Union[Unset, RuleThresholdsModel]): Model that returns the form definition and the form data to edit a
            single rule with all three threshold levels (low, medium, high).
        supports_error_sampling (Union[Unset, bool]): The data quality check supports capturing error samples, because
            an error sampling template is defined.
        supports_grouping (Union[Unset, bool]): The data quality check supports a custom data grouping configuration.
        standard (Union[Unset, bool]): This is a standard data quality check that is always shown on the data quality
            checks editor screen. Non-standard data quality checks (when the value is false) are advanced checks that are
            shown when the user decides to expand the list of checks.
        default_check (Union[Unset, bool]): This is a check that was applied on-the-fly, because it is configured as a
            default data observability check and can be run, but it is not configured in the table YAML.
        default_severity (Union[Unset, DefaultRuleSeverityLevel]):
        data_grouping_override (Union[Unset, DataGroupingConfigurationSpec]):
        schedule_override (Union[Unset, CronScheduleSpec]):
        effective_schedule (Union[Unset, EffectiveScheduleModel]): Model of a configured schedule (enabled on connection
            or table) or schedule override (on check). Describes the CRON expression and the time of the upcoming execution,
            as well as the duration until this time.
        schedule_enabled_status (Union[Unset, ScheduleEnabledStatusModel]):
        comments (Union[Unset, List['CommentSpec']]): Comments for change tracking. Please put comments in this
            collection because YAML comments may be removed when the YAML file is modified by the tool (serialization and
            deserialization will remove non tracked comments).
        disabled (Union[Unset, bool]): Disables the data quality check. Only enabled checks are executed. The sensor
            should be disabled if it should not work, but the configuration of the sensor and rules should be preserved in
            the configuration.
        exclude_from_kpi (Union[Unset, bool]): Data quality check results (alerts) are included in the data quality KPI
            calculation by default. Set this field to true in order to exclude this data quality check from the data quality
            KPI calculation.
        include_in_sla (Union[Unset, bool]): Marks the data quality check as part of a data quality SLA (Data Contract).
            The data quality SLA is a set of critical data quality checks that must always pass and are considered as a Data
            Contract for the dataset.
        configured (Union[Unset, bool]): True if the data quality check is configured (not null). When saving the data
            quality check configuration, set the flag to true for storing the check.
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        run_checks_job_template (Union[Unset, CheckSearchFilters]): Target data quality checks filter, identifies which
            checks on which tables and columns should be executed.
        data_clean_job_template (Union[Unset, DeleteStoredDataQueueJobParameters]):
        data_grouping_configuration (Union[Unset, str]): The name of a data grouping configuration defined at a table
            that should be used for this check.
        always_collect_error_samples (Union[Unset, bool]): Forces collecting error samples for this check whenever it
            fails, even if it is a monitoring check that is run by a scheduler, and running an additional query to collect
            error samples will impose additional load on the data source.
        do_not_schedule (Union[Unset, bool]): Disables running this check by a DQOps CRON scheduler. When a check is
            disabled from scheduling, it can be only triggered from the user interface or by submitting "run checks" job.
        check_target (Union[Unset, CheckTargetModel]):
        configuration_requirements_errors (Union[Unset, List[str]]): List of configuration errors that must be fixed
            before the data quality check can be executed.
        similar_checks (Union[Unset, List['SimilarCheckModel']]): List of similar checks in other check types or in
            other time scales.
        check_hash (Union[Unset, int]): The check hash code that identifies the check instance.
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can edit the check.
        can_run_checks (Union[Unset, bool]): Boolean flag that decides if the current user can run checks.
        can_delete_data (Union[Unset, bool]): Boolean flag that decides if the current user can delete data (results).
        similar_profiling_check (Union[Unset, SimilarCheckModel]): Model that identifies a similar check in another
            category or another type of check (monitoring, partition).
    """

    check_name: Union[Unset, str] = UNSET
    help_text: Union[Unset, str] = UNSET
    display_name: Union[Unset, str] = UNSET
    friendly_name: Union[Unset, str] = UNSET
    sensor_parameters: Union[Unset, List["FieldModel"]] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    rule: Union[Unset, "RuleThresholdsModel"] = UNSET
    supports_error_sampling: Union[Unset, bool] = UNSET
    supports_grouping: Union[Unset, bool] = UNSET
    standard: Union[Unset, bool] = UNSET
    default_check: Union[Unset, bool] = UNSET
    default_severity: Union[Unset, DefaultRuleSeverityLevel] = UNSET
    data_grouping_override: Union[Unset, "DataGroupingConfigurationSpec"] = UNSET
    schedule_override: Union[Unset, "CronScheduleSpec"] = UNSET
    effective_schedule: Union[Unset, "EffectiveScheduleModel"] = UNSET
    schedule_enabled_status: Union[Unset, ScheduleEnabledStatusModel] = UNSET
    comments: Union[Unset, List["CommentSpec"]] = UNSET
    disabled: Union[Unset, bool] = UNSET
    exclude_from_kpi: Union[Unset, bool] = UNSET
    include_in_sla: Union[Unset, bool] = UNSET
    configured: Union[Unset, bool] = UNSET
    filter_: Union[Unset, str] = UNSET
    run_checks_job_template: Union[Unset, "CheckSearchFilters"] = UNSET
    data_clean_job_template: Union[Unset, "DeleteStoredDataQueueJobParameters"] = UNSET
    data_grouping_configuration: Union[Unset, str] = UNSET
    always_collect_error_samples: Union[Unset, bool] = UNSET
    do_not_schedule: Union[Unset, bool] = UNSET
    check_target: Union[Unset, CheckTargetModel] = UNSET
    configuration_requirements_errors: Union[Unset, List[str]] = UNSET
    similar_checks: Union[Unset, List["SimilarCheckModel"]] = UNSET
    check_hash: Union[Unset, int] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    can_run_checks: Union[Unset, bool] = UNSET
    can_delete_data: Union[Unset, bool] = UNSET
    similar_profiling_check: Union[Unset, "SimilarCheckModel"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_name = self.check_name
        help_text = self.help_text
        display_name = self.display_name
        friendly_name = self.friendly_name
        sensor_parameters: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.sensor_parameters, Unset):
            sensor_parameters = []
            for sensor_parameters_item_data in self.sensor_parameters:
                sensor_parameters_item = sensor_parameters_item_data.to_dict()

                sensor_parameters.append(sensor_parameters_item)

        sensor_name = self.sensor_name
        quality_dimension = self.quality_dimension
        rule: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.rule, Unset):
            rule = self.rule.to_dict()

        supports_error_sampling = self.supports_error_sampling
        supports_grouping = self.supports_grouping
        standard = self.standard
        default_check = self.default_check
        default_severity: Union[Unset, str] = UNSET
        if not isinstance(self.default_severity, Unset):
            default_severity = self.default_severity.value

        data_grouping_override: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_grouping_override, Unset):
            data_grouping_override = self.data_grouping_override.to_dict()

        schedule_override: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schedule_override, Unset):
            schedule_override = self.schedule_override.to_dict()

        effective_schedule: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.effective_schedule, Unset):
            effective_schedule = self.effective_schedule.to_dict()

        schedule_enabled_status: Union[Unset, str] = UNSET
        if not isinstance(self.schedule_enabled_status, Unset):
            schedule_enabled_status = self.schedule_enabled_status.value

        comments: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.comments, Unset):
            comments = []
            for comments_item_data in self.comments:
                comments_item = comments_item_data.to_dict()

                comments.append(comments_item)

        disabled = self.disabled
        exclude_from_kpi = self.exclude_from_kpi
        include_in_sla = self.include_in_sla
        configured = self.configured
        filter_ = self.filter_
        run_checks_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.run_checks_job_template, Unset):
            run_checks_job_template = self.run_checks_job_template.to_dict()

        data_clean_job_template: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.data_clean_job_template, Unset):
            data_clean_job_template = self.data_clean_job_template.to_dict()

        data_grouping_configuration = self.data_grouping_configuration
        always_collect_error_samples = self.always_collect_error_samples
        do_not_schedule = self.do_not_schedule
        check_target: Union[Unset, str] = UNSET
        if not isinstance(self.check_target, Unset):
            check_target = self.check_target.value

        configuration_requirements_errors: Union[Unset, List[str]] = UNSET
        if not isinstance(self.configuration_requirements_errors, Unset):
            configuration_requirements_errors = self.configuration_requirements_errors

        similar_checks: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.similar_checks, Unset):
            similar_checks = []
            for similar_checks_item_data in self.similar_checks:
                similar_checks_item = similar_checks_item_data.to_dict()

                similar_checks.append(similar_checks_item)

        check_hash = self.check_hash
        can_edit = self.can_edit
        can_run_checks = self.can_run_checks
        can_delete_data = self.can_delete_data
        similar_profiling_check: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.similar_profiling_check, Unset):
            similar_profiling_check = self.similar_profiling_check.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_name is not UNSET:
            field_dict["check_name"] = check_name
        if help_text is not UNSET:
            field_dict["help_text"] = help_text
        if display_name is not UNSET:
            field_dict["display_name"] = display_name
        if friendly_name is not UNSET:
            field_dict["friendly_name"] = friendly_name
        if sensor_parameters is not UNSET:
            field_dict["sensor_parameters"] = sensor_parameters
        if sensor_name is not UNSET:
            field_dict["sensor_name"] = sensor_name
        if quality_dimension is not UNSET:
            field_dict["quality_dimension"] = quality_dimension
        if rule is not UNSET:
            field_dict["rule"] = rule
        if supports_error_sampling is not UNSET:
            field_dict["supports_error_sampling"] = supports_error_sampling
        if supports_grouping is not UNSET:
            field_dict["supports_grouping"] = supports_grouping
        if standard is not UNSET:
            field_dict["standard"] = standard
        if default_check is not UNSET:
            field_dict["default_check"] = default_check
        if default_severity is not UNSET:
            field_dict["default_severity"] = default_severity
        if data_grouping_override is not UNSET:
            field_dict["data_grouping_override"] = data_grouping_override
        if schedule_override is not UNSET:
            field_dict["schedule_override"] = schedule_override
        if effective_schedule is not UNSET:
            field_dict["effective_schedule"] = effective_schedule
        if schedule_enabled_status is not UNSET:
            field_dict["schedule_enabled_status"] = schedule_enabled_status
        if comments is not UNSET:
            field_dict["comments"] = comments
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if exclude_from_kpi is not UNSET:
            field_dict["exclude_from_kpi"] = exclude_from_kpi
        if include_in_sla is not UNSET:
            field_dict["include_in_sla"] = include_in_sla
        if configured is not UNSET:
            field_dict["configured"] = configured
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if run_checks_job_template is not UNSET:
            field_dict["run_checks_job_template"] = run_checks_job_template
        if data_clean_job_template is not UNSET:
            field_dict["data_clean_job_template"] = data_clean_job_template
        if data_grouping_configuration is not UNSET:
            field_dict["data_grouping_configuration"] = data_grouping_configuration
        if always_collect_error_samples is not UNSET:
            field_dict["always_collect_error_samples"] = always_collect_error_samples
        if do_not_schedule is not UNSET:
            field_dict["do_not_schedule"] = do_not_schedule
        if check_target is not UNSET:
            field_dict["check_target"] = check_target
        if configuration_requirements_errors is not UNSET:
            field_dict["configuration_requirements_errors"] = (
                configuration_requirements_errors
            )
        if similar_checks is not UNSET:
            field_dict["similar_checks"] = similar_checks
        if check_hash is not UNSET:
            field_dict["check_hash"] = check_hash
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if can_run_checks is not UNSET:
            field_dict["can_run_checks"] = can_run_checks
        if can_delete_data is not UNSET:
            field_dict["can_delete_data"] = can_delete_data
        if similar_profiling_check is not UNSET:
            field_dict["similar_profiling_check"] = similar_profiling_check

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.check_search_filters import CheckSearchFilters
        from ..models.comment_spec import CommentSpec
        from ..models.cron_schedule_spec import CronScheduleSpec
        from ..models.data_grouping_configuration_spec import (
            DataGroupingConfigurationSpec,
        )
        from ..models.delete_stored_data_queue_job_parameters import (
            DeleteStoredDataQueueJobParameters,
        )
        from ..models.effective_schedule_model import EffectiveScheduleModel
        from ..models.field_model import FieldModel
        from ..models.rule_thresholds_model import RuleThresholdsModel
        from ..models.similar_check_model import SimilarCheckModel

        d = src_dict.copy()
        check_name = d.pop("check_name", UNSET)

        help_text = d.pop("help_text", UNSET)

        display_name = d.pop("display_name", UNSET)

        friendly_name = d.pop("friendly_name", UNSET)

        sensor_parameters = []
        _sensor_parameters = d.pop("sensor_parameters", UNSET)
        for sensor_parameters_item_data in _sensor_parameters or []:
            sensor_parameters_item = FieldModel.from_dict(sensor_parameters_item_data)

            sensor_parameters.append(sensor_parameters_item)

        sensor_name = d.pop("sensor_name", UNSET)

        quality_dimension = d.pop("quality_dimension", UNSET)

        _rule = d.pop("rule", UNSET)
        rule: Union[Unset, RuleThresholdsModel]
        if isinstance(_rule, Unset):
            rule = UNSET
        else:
            rule = RuleThresholdsModel.from_dict(_rule)

        supports_error_sampling = d.pop("supports_error_sampling", UNSET)

        supports_grouping = d.pop("supports_grouping", UNSET)

        standard = d.pop("standard", UNSET)

        default_check = d.pop("default_check", UNSET)

        _default_severity = d.pop("default_severity", UNSET)
        default_severity: Union[Unset, DefaultRuleSeverityLevel]
        if isinstance(_default_severity, Unset):
            default_severity = UNSET
        else:
            default_severity = DefaultRuleSeverityLevel(_default_severity)

        _data_grouping_override = d.pop("data_grouping_override", UNSET)
        data_grouping_override: Union[Unset, DataGroupingConfigurationSpec]
        if isinstance(_data_grouping_override, Unset):
            data_grouping_override = UNSET
        else:
            data_grouping_override = DataGroupingConfigurationSpec.from_dict(
                _data_grouping_override
            )

        _schedule_override = d.pop("schedule_override", UNSET)
        schedule_override: Union[Unset, CronScheduleSpec]
        if isinstance(_schedule_override, Unset):
            schedule_override = UNSET
        else:
            schedule_override = CronScheduleSpec.from_dict(_schedule_override)

        _effective_schedule = d.pop("effective_schedule", UNSET)
        effective_schedule: Union[Unset, EffectiveScheduleModel]
        if isinstance(_effective_schedule, Unset):
            effective_schedule = UNSET
        else:
            effective_schedule = EffectiveScheduleModel.from_dict(_effective_schedule)

        _schedule_enabled_status = d.pop("schedule_enabled_status", UNSET)
        schedule_enabled_status: Union[Unset, ScheduleEnabledStatusModel]
        if isinstance(_schedule_enabled_status, Unset):
            schedule_enabled_status = UNSET
        else:
            schedule_enabled_status = ScheduleEnabledStatusModel(
                _schedule_enabled_status
            )

        comments = []
        _comments = d.pop("comments", UNSET)
        for comments_item_data in _comments or []:
            comments_item = CommentSpec.from_dict(comments_item_data)

            comments.append(comments_item)

        disabled = d.pop("disabled", UNSET)

        exclude_from_kpi = d.pop("exclude_from_kpi", UNSET)

        include_in_sla = d.pop("include_in_sla", UNSET)

        configured = d.pop("configured", UNSET)

        filter_ = d.pop("filter", UNSET)

        _run_checks_job_template = d.pop("run_checks_job_template", UNSET)
        run_checks_job_template: Union[Unset, CheckSearchFilters]
        if isinstance(_run_checks_job_template, Unset):
            run_checks_job_template = UNSET
        else:
            run_checks_job_template = CheckSearchFilters.from_dict(
                _run_checks_job_template
            )

        _data_clean_job_template = d.pop("data_clean_job_template", UNSET)
        data_clean_job_template: Union[Unset, DeleteStoredDataQueueJobParameters]
        if isinstance(_data_clean_job_template, Unset):
            data_clean_job_template = UNSET
        else:
            data_clean_job_template = DeleteStoredDataQueueJobParameters.from_dict(
                _data_clean_job_template
            )

        data_grouping_configuration = d.pop("data_grouping_configuration", UNSET)

        always_collect_error_samples = d.pop("always_collect_error_samples", UNSET)

        do_not_schedule = d.pop("do_not_schedule", UNSET)

        _check_target = d.pop("check_target", UNSET)
        check_target: Union[Unset, CheckTargetModel]
        if isinstance(_check_target, Unset):
            check_target = UNSET
        else:
            check_target = CheckTargetModel(_check_target)

        configuration_requirements_errors = cast(
            List[str], d.pop("configuration_requirements_errors", UNSET)
        )

        similar_checks = []
        _similar_checks = d.pop("similar_checks", UNSET)
        for similar_checks_item_data in _similar_checks or []:
            similar_checks_item = SimilarCheckModel.from_dict(similar_checks_item_data)

            similar_checks.append(similar_checks_item)

        check_hash = d.pop("check_hash", UNSET)

        can_edit = d.pop("can_edit", UNSET)

        can_run_checks = d.pop("can_run_checks", UNSET)

        can_delete_data = d.pop("can_delete_data", UNSET)

        _similar_profiling_check = d.pop("similar_profiling_check", UNSET)
        similar_profiling_check: Union[Unset, SimilarCheckModel]
        if isinstance(_similar_profiling_check, Unset):
            similar_profiling_check = UNSET
        else:
            similar_profiling_check = SimilarCheckModel.from_dict(
                _similar_profiling_check
            )

        check_model = cls(
            check_name=check_name,
            help_text=help_text,
            display_name=display_name,
            friendly_name=friendly_name,
            sensor_parameters=sensor_parameters,
            sensor_name=sensor_name,
            quality_dimension=quality_dimension,
            rule=rule,
            supports_error_sampling=supports_error_sampling,
            supports_grouping=supports_grouping,
            standard=standard,
            default_check=default_check,
            default_severity=default_severity,
            data_grouping_override=data_grouping_override,
            schedule_override=schedule_override,
            effective_schedule=effective_schedule,
            schedule_enabled_status=schedule_enabled_status,
            comments=comments,
            disabled=disabled,
            exclude_from_kpi=exclude_from_kpi,
            include_in_sla=include_in_sla,
            configured=configured,
            filter_=filter_,
            run_checks_job_template=run_checks_job_template,
            data_clean_job_template=data_clean_job_template,
            data_grouping_configuration=data_grouping_configuration,
            always_collect_error_samples=always_collect_error_samples,
            do_not_schedule=do_not_schedule,
            check_target=check_target,
            configuration_requirements_errors=configuration_requirements_errors,
            similar_checks=similar_checks,
            check_hash=check_hash,
            can_edit=can_edit,
            can_run_checks=can_run_checks,
            can_delete_data=can_delete_data,
            similar_profiling_check=similar_profiling_check,
        )

        check_model.additional_properties = d
        return check_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ColumnNumericPercentileSensorParametersSpec")


@_attrs_define
class ColumnNumericPercentileSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        percentile_value (Union[Unset, float]): Must be a literal in the range [0, 1].
    """

    filter_: Union[Unset, str] = UNSET
    percentile_value: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        percentile_value = self.percentile_value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if percentile_value is not UNSET:
            field_dict["percentile_value"] = percentile_value

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        percentile_value = d.pop("percentile_value", UNSET)

        column_numeric_percentile_sensor_parameters_spec = cls(
            filter_=filter_,
            percentile_value=percentile_value,
        )

        column_numeric_percentile_sensor_parameters_spec.additional_properties = d
        return column_numeric_percentile_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.rule_folder_model_folders import RuleFolderModelFolders
    from ..models.rule_list_model import RuleListModel


T = TypeVar("T", bound="RuleFolderModel")


@_attrs_define
class RuleFolderModel:
    """Rule folder model with a list of rules defined in this folder and nested folders that contain additional rules.

    Attributes:
        folders (Union[Unset, RuleFolderModelFolders]): A dictionary of nested folders with rules, the keys are the
            folder names.
        rules (Union[Unset, List['RuleListModel']]): List of rules defined in this folder.
        all_rules (Union[Unset, List['RuleListModel']]):
    """

    folders: Union[Unset, "RuleFolderModelFolders"] = UNSET
    rules: Union[Unset, List["RuleListModel"]] = UNSET
    all_rules: Union[Unset, List["RuleListModel"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        folders: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.folders, Unset):
            folders = self.folders.to_dict()

        rules: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.rules, Unset):
            rules = []
            for rules_item_data in self.rules:
                rules_item = rules_item_data.to_dict()

                rules.append(rules_item)

        all_rules: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.all_rules, Unset):
            all_rules = []
            for all_rules_item_data in self.all_rules:
                all_rules_item = all_rules_item_data.to_dict()

                all_rules.append(all_rules_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if folders is not UNSET:
            field_dict["folders"] = folders
        if rules is not UNSET:
            field_dict["rules"] = rules
        if all_rules is not UNSET:
            field_dict["all_rules"] = all_rules

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.rule_folder_model_folders import RuleFolderModelFolders
        from ..models.rule_list_model import RuleListModel

        d = src_dict.copy()
        _folders = d.pop("folders", UNSET)
        folders: Union[Unset, RuleFolderModelFolders]
        if isinstance(_folders, Unset):
            folders = UNSET
        else:
            folders = RuleFolderModelFolders.from_dict(_folders)

        rules = []
        _rules = d.pop("rules", UNSET)
        for rules_item_data in _rules or []:
            rules_item = RuleListModel.from_dict(rules_item_data)

            rules.append(rules_item)

        all_rules = []
        _all_rules = d.pop("all_rules", UNSET)
        for all_rules_item_data in _all_rules or []:
            all_rules_item = RuleListModel.from_dict(all_rules_item_data)

            all_rules.append(all_rules_item)

        rule_folder_model = cls(
            folders=folders,
            rules=rules,
            all_rules=all_rules,
        )

        rule_folder_model.additional_properties = d
        return rule_folder_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.physical_table_name import PhysicalTableName


T = TypeVar("T", bound="TableProfilingSetupStatusModel")


@_attrs_define
class TableProfilingSetupStatusModel:
    """Table status model that identifies which type of information is already collected, such as data quality checks are
    configured, or statistics collected.

        Attributes:
            connection_name (Union[Unset, str]): Connection name.
            table_hash (Union[Unset, int]): Table hash that identifies the table using a unique hash code.
            target (Union[Unset, PhysicalTableName]):
            basic_statistics_collected (Union[Unset, bool]): The basic statistics were collected for this table. If this
                field returns false, the statistics were not collected and the user should collect basic statistics again.
            profiling_checks_configured (Union[Unset, bool]): Returns true if the table has any profiling checks configured
                on the table, or any of its column. Returns false when the user should first generate a configuration of the
                profiling checks using the rule miner.
            monitoring_checks_configured (Union[Unset, bool]): Returns true if the table has any monitoring checks
                configured on the table, or any of its column. Returns false when the user should first generate a configuration
                of the monitoring checks using the rule miner.
            partition_checks_configured (Union[Unset, bool]): Returns true if the table has any partition checks configured
                on the table, or any of its column. The value is true also when the table is not configured to support
                partitioned checks, so asking the user to configure partition checks is useless. Returns false when the user
                should first generate a configuration of the partition checks using the rule miner.
            check_results_present (Union[Unset, bool]): Returns true if the table has any recent data quality check results.
                Returns false when the user should run any checks to get any results.
    """

    connection_name: Union[Unset, str] = UNSET
    table_hash: Union[Unset, int] = UNSET
    target: Union[Unset, "PhysicalTableName"] = UNSET
    basic_statistics_collected: Union[Unset, bool] = UNSET
    profiling_checks_configured: Union[Unset, bool] = UNSET
    monitoring_checks_configured: Union[Unset, bool] = UNSET
    partition_checks_configured: Union[Unset, bool] = UNSET
    check_results_present: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_name = self.connection_name
        table_hash = self.table_hash
        target: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target, Unset):
            target = self.target.to_dict()

        basic_statistics_collected = self.basic_statistics_collected
        profiling_checks_configured = self.profiling_checks_configured
        monitoring_checks_configured = self.monitoring_checks_configured
        partition_checks_configured = self.partition_checks_configured
        check_results_present = self.check_results_present

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_name is not UNSET:
            field_dict["connection_name"] = connection_name
        if table_hash is not UNSET:
            field_dict["table_hash"] = table_hash
        if target is not UNSET:
            field_dict["target"] = target
        if basic_statistics_collected is not UNSET:
            field_dict["basic_statistics_collected"] = basic_statistics_collected
        if profiling_checks_configured is not UNSET:
            field_dict["profiling_checks_configured"] = profiling_checks_configured
        if monitoring_checks_configured is not UNSET:
            field_dict["monitoring_checks_configured"] = monitoring_checks_configured
        if partition_checks_configured is not UNSET:
            field_dict["partition_checks_configured"] = partition_checks_configured
        if check_results_present is not UNSET:
            field_dict["check_results_present"] = check_results_present

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.physical_table_name import PhysicalTableName

        d = src_dict.copy()
        connection_name = d.pop("connection_name", UNSET)

        table_hash = d.pop("table_hash", UNSET)

        _target = d.pop("target", UNSET)
        target: Union[Unset, PhysicalTableName]
        if isinstance(_target, Unset):
            target = UNSET
        else:
            target = PhysicalTableName.from_dict(_target)

        basic_statistics_collected = d.pop("basic_statistics_collected", UNSET)

        profiling_checks_configured = d.pop("profiling_checks_configured", UNSET)

        monitoring_checks_configured = d.pop("monitoring_checks_configured", UNSET)

        partition_checks_configured = d.pop("partition_checks_configured", UNSET)

        check_results_present = d.pop("check_results_present", UNSET)

        table_profiling_setup_status_model = cls(
            connection_name=connection_name,
            table_hash=table_hash,
            target=target,
            basic_statistics_collected=basic_statistics_collected,
            profiling_checks_configured=profiling_checks_configured,
            monitoring_checks_configured=monitoring_checks_configured,
            partition_checks_configured=partition_checks_configured,
            check_results_present=check_results_present,
        )

        table_profiling_setup_status_model.additional_properties = d
        return table_profiling_setup_status_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ProviderType(str, Enum):
    BIGQUERY = "bigquery"
    CLICKHOUSE = "clickhouse"
    DATABRICKS = "databricks"
    DB2 = "db2"
    DUCKDB = "duckdb"
    HANA = "hana"
    MARIADB = "mariadb"
    MYSQL = "mysql"
    ORACLE = "oracle"
    POSTGRESQL = "postgresql"
    PRESTO = "presto"
    QUESTDB = "questdb"
    REDSHIFT = "redshift"
    SNOWFLAKE = "snowflake"
    SPARK = "spark"
    SQLSERVER = "sqlserver"
    TERADATA = "teradata"
    TRINO = "trino"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.target_column_pattern_spec import TargetColumnPatternSpec


T = TypeVar("T", bound="ColumnQualityPolicyListModel")


@_attrs_define
class ColumnQualityPolicyListModel:
    """Default column-level checks pattern (data quality policy) list model

    Attributes:
        policy_name (Union[Unset, str]): Quality policy name.
        priority (Union[Unset, int]): The priority of the policy. Policies with lower values are applied before policies
            with higher priority values.
        disabled (Union[Unset, bool]): Disables this data quality check configuration. The checks will not be activated.
        description (Union[Unset, str]): The description (documentation) of this data quality check configuration.
        target_column (Union[Unset, TargetColumnPatternSpec]):
        can_edit (Union[Unset, bool]): Boolean flag that decides if the current user can update or delete this object.
        yaml_parsing_error (Union[Unset, str]): Optional parsing error that was captured when parsing the YAML file.
            This field is null when the YAML file is valid. If an error was captured, this field returns the file parsing
            error message and the file location.
    """

    policy_name: Union[Unset, str] = UNSET
    priority: Union[Unset, int] = UNSET
    disabled: Union[Unset, bool] = UNSET
    description: Union[Unset, str] = UNSET
    target_column: Union[Unset, "TargetColumnPatternSpec"] = UNSET
    can_edit: Union[Unset, bool] = UNSET
    yaml_parsing_error: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        policy_name = self.policy_name
        priority = self.priority
        disabled = self.disabled
        description = self.description
        target_column: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.target_column, Unset):
            target_column = self.target_column.to_dict()

        can_edit = self.can_edit
        yaml_parsing_error = self.yaml_parsing_error

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if policy_name is not UNSET:
            field_dict["policy_name"] = policy_name
        if priority is not UNSET:
            field_dict["priority"] = priority
        if disabled is not UNSET:
            field_dict["disabled"] = disabled
        if description is not UNSET:
            field_dict["description"] = description
        if target_column is not UNSET:
            field_dict["target_column"] = target_column
        if can_edit is not UNSET:
            field_dict["can_edit"] = can_edit
        if yaml_parsing_error is not UNSET:
            field_dict["yaml_parsing_error"] = yaml_parsing_error

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.target_column_pattern_spec import TargetColumnPatternSpec

        d = src_dict.copy()
        policy_name = d.pop("policy_name", UNSET)

        priority = d.pop("priority", UNSET)

        disabled = d.pop("disabled", UNSET)

        description = d.pop("description", UNSET)

        _target_column = d.pop("target_column", UNSET)
        target_column: Union[Unset, TargetColumnPatternSpec]
        if isinstance(_target_column, Unset):
            target_column = UNSET
        else:
            target_column = TargetColumnPatternSpec.from_dict(_target_column)

        can_edit = d.pop("can_edit", UNSET)

        yaml_parsing_error = d.pop("yaml_parsing_error", UNSET)

        column_quality_policy_list_model = cls(
            policy_name=policy_name,
            priority=priority,
            disabled=disabled,
            description=description,
            target_column=target_column,
            can_edit=can_edit,
            yaml_parsing_error=yaml_parsing_error,
        )

        column_quality_policy_list_model.additional_properties = d
        return column_quality_policy_list_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class RuleTimeWindowMode(str, Enum):
    CURRENT_VALUE = "current_value"
    PREVIOUS_READOUTS = "previous_readouts"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class JsonFormatType(str, Enum):
    ARRAY = "array"
    AUTO = "auto"
    NEWLINE_DELIMITED = "newline_delimited"
    UNSTRUCTURED = "unstructured"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ColumnIntegrityForeignKeyMatchPercentSensorParametersSpec")


@_attrs_define
class ColumnIntegrityForeignKeyMatchPercentSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        foreign_table (Union[Unset, str]): This field can be used to define the name of the table to be compared to. In
            order to define the name of the table, user should write correct name as a String.
        foreign_column (Union[Unset, str]): This field can be used to define the name of the column to be compared to.
            In order to define the name of the column, user should write correct name as a String.
    """

    filter_: Union[Unset, str] = UNSET
    foreign_table: Union[Unset, str] = UNSET
    foreign_column: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        foreign_table = self.foreign_table
        foreign_column = self.foreign_column

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if foreign_table is not UNSET:
            field_dict["foreign_table"] = foreign_table
        if foreign_column is not UNSET:
            field_dict["foreign_column"] = foreign_column

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        foreign_table = d.pop("foreign_table", UNSET)

        foreign_column = d.pop("foreign_column", UNSET)

        column_integrity_foreign_key_match_percent_sensor_parameters_spec = cls(
            filter_=filter_,
            foreign_table=foreign_table,
            foreign_column=foreign_column,
        )

        column_integrity_foreign_key_match_percent_sensor_parameters_spec.additional_properties = (
            d
        )
        return column_integrity_foreign_key_match_percent_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="LocalDataDomainModel")


@_attrs_define
class LocalDataDomainModel:
    """Model that describes a local data domain. It is also used to create new data domains.

    Attributes:
        domain_name (Union[Unset, str]): Data domain name.
        display_name (Union[Unset, str]): Data domain display name (user-friendly name).
        created_at (Union[Unset, int]): Data domain creation time.
        enable_scheduler (Union[Unset, bool]): Enables the job scheduler for this domain.
    """

    domain_name: Union[Unset, str] = UNSET
    display_name: Union[Unset, str] = UNSET
    created_at: Union[Unset, int] = UNSET
    enable_scheduler: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        domain_name = self.domain_name
        display_name = self.display_name
        created_at = self.created_at
        enable_scheduler = self.enable_scheduler

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if domain_name is not UNSET:
            field_dict["domain_name"] = domain_name
        if display_name is not UNSET:
            field_dict["display_name"] = display_name
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if enable_scheduler is not UNSET:
            field_dict["enable_scheduler"] = enable_scheduler

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        domain_name = d.pop("domain_name", UNSET)

        display_name = d.pop("display_name", UNSET)

        created_at = d.pop("created_at", UNSET)

        enable_scheduler = d.pop("enable_scheduler", UNSET)

        local_data_domain_model = cls(
            domain_name=domain_name,
            display_name=display_name,
            created_at=created_at,
            enable_scheduler=enable_scheduler,
        )

        local_data_domain_model.additional_properties = d
        return local_data_domain_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="IncidentCountsModel")


@_attrs_define
class IncidentCountsModel:
    """
    Attributes:
        total_count (Union[Unset, int]): Number of incidents in total.
        count_from_last_24_h (Union[Unset, int]): Number of incidents from the last 24h from now.
        count_from_last_7_days (Union[Unset, int]): Number of incidents from the last 7 days, the number of 7 * 24 hours
            from now.
        current_month_count (Union[Unset, int]): Number of incidents from the complete current month.
        current_month_date (Union[Unset, datetime.date]): The first day of the current month date.
        previous_month_count (Union[Unset, int]): Number of incidents from the complete previous month.
        previous_month_date (Union[Unset, datetime.date]): The first day of the previous month date.
    """

    total_count: Union[Unset, int] = UNSET
    count_from_last_24_h: Union[Unset, int] = UNSET
    count_from_last_7_days: Union[Unset, int] = UNSET
    current_month_count: Union[Unset, int] = UNSET
    current_month_date: Union[Unset, datetime.date] = UNSET
    previous_month_count: Union[Unset, int] = UNSET
    previous_month_date: Union[Unset, datetime.date] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        total_count = self.total_count
        count_from_last_24_h = self.count_from_last_24_h
        count_from_last_7_days = self.count_from_last_7_days
        current_month_count = self.current_month_count
        current_month_date: Union[Unset, str] = UNSET
        if not isinstance(self.current_month_date, Unset):
            current_month_date = self.current_month_date.isoformat()

        previous_month_count = self.previous_month_count
        previous_month_date: Union[Unset, str] = UNSET
        if not isinstance(self.previous_month_date, Unset):
            previous_month_date = self.previous_month_date.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if total_count is not UNSET:
            field_dict["totalCount"] = total_count
        if count_from_last_24_h is not UNSET:
            field_dict["countFromLast24h"] = count_from_last_24_h
        if count_from_last_7_days is not UNSET:
            field_dict["countFromLast7days"] = count_from_last_7_days
        if current_month_count is not UNSET:
            field_dict["currentMonthCount"] = current_month_count
        if current_month_date is not UNSET:
            field_dict["currentMonthDate"] = current_month_date
        if previous_month_count is not UNSET:
            field_dict["previousMonthCount"] = previous_month_count
        if previous_month_date is not UNSET:
            field_dict["previousMonthDate"] = previous_month_date

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        total_count = d.pop("totalCount", UNSET)

        count_from_last_24_h = d.pop("countFromLast24h", UNSET)

        count_from_last_7_days = d.pop("countFromLast7days", UNSET)

        current_month_count = d.pop("currentMonthCount", UNSET)

        _current_month_date = d.pop("currentMonthDate", UNSET)
        current_month_date: Union[Unset, datetime.date]
        if isinstance(_current_month_date, Unset):
            current_month_date = UNSET
        else:
            current_month_date = isoparse(_current_month_date).date()

        previous_month_count = d.pop("previousMonthCount", UNSET)

        _previous_month_date = d.pop("previousMonthDate", UNSET)
        previous_month_date: Union[Unset, datetime.date]
        if isinstance(_previous_month_date, Unset):
            previous_month_date = UNSET
        else:
            previous_month_date = isoparse(_previous_month_date).date()

        incident_counts_model = cls(
            total_count=total_count,
            count_from_last_24_h=count_from_last_24_h,
            count_from_last_7_days=count_from_last_7_days,
            current_month_count=current_month_count,
            current_month_date=current_month_date,
            previous_month_count=previous_month_count,
            previous_month_date=previous_month_date,
        )

        incident_counts_model.additional_properties = d
        return incident_counts_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.shared_credential_model import SharedCredentialModel
from ...types import Response


def _get_kwargs(
    credential_name: str,
    *,
    json_body: SharedCredentialModel,
) -> Dict[str, Any]:

    pass

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": "api/credential/{credentialName}".format(
            credentialName=credential_name,
        ),
        "json": json_json_body,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == HTTPStatus.NO_CONTENT:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    credential_name: str,
    *,
    client: AuthenticatedClient,
    json_body: SharedCredentialModel,
) -> Response[Any]:
    """updateSharedCredential

     Updates an existing shared credential, replacing the credential's file content.

    Args:
        credential_name (str):
        json_body (SharedCredentialModel): Shared credentials full model used to create and update
            the credential. Contains one of two forms of the credential's value: a text or a base64
            binary value.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        credential_name=credential_name,
        json_body=json_body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    credential_name: str,
    *,
    client: AuthenticatedClient,
    json_body: SharedCredentialModel,
) -> Response[Any]:
    """updateSharedCredential

     Updates an existing shared credential, replacing the credential's file content.

    Args:
        credential_name (str):
        json_body (SharedCredentialModel): Shared credentials full model used to create and update
            the credential. Contains one of two forms of the credential's value: a text or a base64
            binary value.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        credential_name=credential_name,
        json_body=json_body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)
